@@ -7,7 +7,7 @@
 #include "util/uuid.hpp"
 #include "bom_export_settings.hpp"
 #include "block_instance.hpp"
-#include <fstream>
+#include "net_tie.hpp"
 #include <map>
 #include <set>
 #include <vector>
@@ -37,6 +37,7 @@ public:
     UUID uuid;
     std::string name;
     std::map<UUID, Net> nets;
+    std::map<UUID, NetTie> net_ties;
     std::map<UUID, Bus> buses;
     std::map<UUID, Component> components;
     std::map<UUID, BlockInstance> block_instances;
@@ -119,6 +120,8 @@ public:
     std::vector<BlockItem<false>> get_instantiated_blocks_and_top();
     std::vector<BlockItem<true>> get_instantiated_blocks_and_top() const;
 
+    std::string instance_path_to_string(const UUIDVec &instance_path) const;
+
     bool can_delete_power_net(const UUID &uu) const;
 
     bool can_add_block_instance(const UUID &where, const UUID &block_inst) const;
