@@ -17,6 +17,7 @@
 #include "rule_thermals.hpp"
 #include "rule_net_ties.hpp"
 #include "rule_board_connectivity.hpp"
+#include "rule_via_definitions.hpp"
 #include "rules/rules.hpp"
 #include "util/uuid.hpp"
 #include <atomic>
@@ -44,14 +45,15 @@ public:
     void cleanup(const class Block *block);
 
     uint64_t get_default_track_width(const class Net *net, int layer) const;
-    const RuleClearanceCopper *get_clearance_copper(const Net *net_a, const Net *net_b, int layer) const;
-    const RuleClearanceCopperOther *get_clearance_copper_other(const Net *net, int layer) const;
-    const RuleDiffpair *get_diffpair(const NetClass *net_class, int layer) const;
-    const RuleClearanceCopperKeepout *get_clearance_copper_keepout(const Net *net, const KeepoutContour *contour) const;
-    const RuleClearanceSameNet *get_clearance_same_net(const Net *net, int layer) const;
+    const RuleClearanceCopper &get_clearance_copper(const Net *net_a, const Net *net_b, int layer) const;
+    const RuleClearanceCopperOther &get_clearance_copper_other(const Net *net, int layer) const;
+    const RuleDiffpair &get_diffpair(const NetClass *net_class, int layer) const;
+    const RuleClearanceCopperKeepout &get_clearance_copper_keepout(const Net *net, const KeepoutContour *contour) const;
+    const RuleClearanceSameNet &get_clearance_same_net(const Net *net, int layer) const;
     uint64_t get_max_clearance() const;
 
-    const RuleParameters *get_parameters() const;
+    const RuleParameters &get_parameters() const;
+    const RuleViaDefinitions &get_via_definitions() const;
 
     UUID get_via_padstack_uuid(const class Net *net) const;
     const ParameterSet &get_via_parameter_set(const class Net *net) const;
@@ -70,6 +72,8 @@ public:
         return true;
     }
 
+    void update_for_board(const Board &brd);
+
 private:
     std::map<UUID, RuleHoleSize> rule_hole_size;
     std::map<UUID, RuleTrackWidth> rule_track_width;
@@ -92,7 +96,7 @@ private:
     RulePreflightChecks rule_preflight_checks;
     RuleNetTies rule_net_ties;
     RuleBoardConnectivity rule_board_connectivity;
-
+    RuleViaDefinitions rule_via_definitions;
 
     RulesCheckResult check_track_width(const class Board &b) const;
     RulesCheckResult check_hole_size(const class Board &b) const;
