@@ -83,7 +83,11 @@ Plane::Plane(const UUID &uu, const json &j, Board *brd)
 {
     if (brd) {
         net.update(brd->block->nets);
+        if (net == nullptr)
+            throw std::runtime_error("net " + static_cast<std::string>(net.uuid) + " not found");
         polygon.update(brd->polygons);
+        if (polygon == nullptr)
+            throw std::runtime_error("polygon " + static_cast<std::string>(polygon.uuid) + " not found");
     }
     if (j.count("settings")) {
         settings = PlaneSettings(j.at("settings"));
@@ -99,9 +103,9 @@ Plane::Plane(const UUID &uu) : uuid(uu)
 {
 }
 
-PolygonUsage::Type Plane::get_type() const
+ObjectType Plane::get_type() const
 {
-    return PolygonUsage::Type::PLANE;
+    return ObjectType::PLANE;
 }
 
 UUID Plane::get_uuid() const
