@@ -8,18 +8,15 @@ namespace horizon {
 
 RuleClearanceSameNet::RuleClearanceSameNet(const UUID &uu) : Rule(uu)
 {
-    id = RuleID::CLEARANCE_SAME_NET;
 }
 
 RuleClearanceSameNet::RuleClearanceSameNet(const UUID &uu, const json &j, const RuleImportMap &import_map)
     : Rule(uu, j, import_map), match(j.at("match"), import_map), layer(j.at("layer"))
 {
-    id = RuleID::CLEARANCE_SAME_NET;
-
-    for (const auto &value : j.at("clearances")) {
-        PatchType a = patch_type_lut.lookup(value.at("types").at(0));
-        PatchType b = patch_type_lut.lookup(value.at("types").at(1));
-        set_clearance(a, b, value.at("clearance"));
+    for (const auto &va : j.at("clearances")) {
+        PatchType a = patch_type_lut.lookup(va.at("types").at(0));
+        PatchType b = patch_type_lut.lookup(va.at("types").at(1));
+        set_clearance(a, b, va.at("clearance").get<uint64_t>());
     }
 }
 
@@ -68,11 +65,11 @@ json RuleClearanceSameNet::serialize() const
     return j;
 }
 
-std::string RuleClearanceSameNet::get_brief(const class Block *block) const
+std::string RuleClearanceSameNet::get_brief(const class Block *block, class IPool *pool) const
 {
     std::stringstream ss;
     ss << "Match " << match.get_brief(block) << "\n";
-    ss << "Layer " << layer;
+    ss << layer_to_string(layer);
     return ss.str();
 }
 
