@@ -7,13 +7,11 @@ namespace horizon {
 
 RuleLayerPair::RuleLayerPair(const UUID &uu) : Rule(uu)
 {
-    id = RuleID::LAYER_PAIR;
 }
 
 RuleLayerPair::RuleLayerPair(const UUID &uu, const json &j, const RuleImportMap &import_map)
     : Rule(uu, j, import_map), match(j.at("match"), import_map), layers(j.at("layers"))
 {
-    id = RuleID::LAYER_PAIR;
 }
 
 json RuleLayerPair::serialize() const
@@ -24,7 +22,7 @@ json RuleLayerPair::serialize() const
     return j;
 }
 
-std::string RuleLayerPair::get_brief(const class Block *block) const
+std::string RuleLayerPair::get_brief(const class Block *block, class IPool *pool) const
 {
     return "Match " + match.get_brief(block);
 }
