@@ -6,13 +6,11 @@
 namespace horizon {
 RulePlane::RulePlane(const UUID &uu) : Rule(uu)
 {
-    id = RuleID::PLANE;
 }
 
 RulePlane::RulePlane(const UUID &uu, const json &j, const RuleImportMap &import_map)
     : Rule(uu, j, import_map), match(j.at("match"), import_map), layer(j.at("layer")), settings(j.at("settings"))
 {
-    id = RuleID::PLANE;
 }
 
 json RulePlane::serialize() const
@@ -24,9 +22,9 @@ json RulePlane::serialize() const
     return j;
 }
 
-std::string RulePlane::get_brief(const class Block *block) const
+std::string RulePlane::get_brief(const class Block *block, class IPool *pool) const
 {
-    return "Match " + match.get_brief(block) + "\nLayer " + std::to_string(layer);
+    return "Match " + match.get_brief(block) + "\n" + layer_to_string(layer);
 }
 
 bool RulePlane::is_match_all() const
