@@ -6,6 +6,12 @@
 namespace horizon {
 class RuleTrackWidth : public Rule {
 public:
+    static const auto id = RuleID::TRACK_WIDTH;
+    RuleID get_id() const override
+    {
+        return id;
+    }
+
     class Widths {
     public:
         Widths();
@@ -21,7 +27,7 @@ public:
     RuleTrackWidth(const UUID &uu, const json &j, const RuleImportMap &import_map);
     json serialize() const override;
 
-    std::string get_brief(const class Block *block = nullptr) const override;
+    std::string get_brief(const class Block *block = nullptr, class IPool *pool = nullptr) const override;
     bool is_match_all() const override;
     bool can_export() const override;
 
