@@ -6,7 +6,6 @@
 namespace horizon {
 RuleVia::RuleVia(const UUID &uu) : Rule(uu)
 {
-    id = RuleID::VIA;
     parameter_set[ParameterID::VIA_DIAMETER] = .5_mm;
     parameter_set[ParameterID::HOLE_DIAMETER] = .2_mm;
 }
@@ -15,7 +14,6 @@ RuleVia::RuleVia(const UUID &uu, const json &j, const RuleImportMap &import_map)
     : Rule(uu, j, import_map), match(j.at("match"), import_map), padstack(j.at("padstack").get<std::string>()),
       parameter_set(parameter_set_from_json(j.at("parameter_set")))
 {
-    id = RuleID::VIA;
 }
 
 json RuleVia::serialize() const
@@ -27,7 +25,7 @@ json RuleVia::serialize() const
     return j;
 }
 
-std::string RuleVia::get_brief(const class Block *block) const
+std::string RuleVia::get_brief(const class Block *block, class IPool *pool) const
 {
     return "Match " + match.get_brief(block);
 }
