@@ -8,10 +8,7 @@ namespace horizon {
 
 static GLuint create_vao(GLuint program, GLuint &vbo_out)
 {
-    auto err = glGetError();
-    if (err != GL_NO_ERROR) {
-        std::cout << "gl error a " << err << std::endl;
-    }
+    GL_CHECK_ERROR
     GLuint position_index = glGetAttribLocation(program, "position");
     GLuint color_index = glGetAttribLocation(program, "color");
     GLuint flags_index = glGetAttribLocation(program, "flags");
@@ -54,18 +51,21 @@ static GLuint create_vao(GLuint program, GLuint &vbo_out)
 
 Markers::Markers(CanvasGL &c) : ca(c)
 {
-    std::fill(domains_visible.begin(), domains_visible.end(), false);
+    for (auto &it : domains) {
+        it.visible = false;
+    }
 }
 
 void Markers::set_domain_visible(MarkerDomain dom, bool vis)
 {
-    domains_visible.at(static_cast<int>(dom)) = vis;
+    domains.at(static_cast<int>(dom)).visible = vis;
     ca.update_markers();
+    ca.set_has_tooltip(std::any_of(domains.begin(), domains.end(), [](auto &x) { return x.visible; }));
 }
 
 std::deque<MarkerRef> &Markers::get_domain(MarkerDomain dom)
 {
-    return domains.at(static_cast<int>(dom));
+    return domains.at(static_cast<int>(dom)).markers;
 }
 
 void Markers::update()
@@ -80,6 +80,37 @@ void Markers::set_sheet_filter(const UUIDVec &uu)
     update();
 }
 
+bool Markers::marker_is_visible(const MarkerRef &mkr) const
+{
+    return mkr.visible && (mkr.sheet == sheet_filter || mkr.sheet.size() == 0);
+}
+
+bool Markers::hit_test_marker_ref(const MarkerRef &ref, const Coordf &p) const
+{
+    const auto size_px = ref.size == MarkerRef::Size::DEFAULT ? 40 : 20; // see geometry shader
+    const auto size_canvas = size_px / ca.scale;
+    const auto a = ref.position;
+    const auto b = ref.position + Coordf(size_canvas, -size_canvas);
+    return p.x >= a.x && p.x <= b.x && p.y >= b.y && p.y <= a.y;
+}
+
+std::vector<const MarkerRef *> Markers::get_markers_at_screen_pos(int x, int y) const
+{
+    const auto canvas_pos = ca.screen2canvas(Coordf(x, y));
+    std::vector<const MarkerRef *> r;
+    for (const auto &dom : domains) {
+        if (dom.visible) {
+            for (const auto &mrk : dom.markers) {
+                if (marker_is_visible(mrk) && hit_test_marker_ref(mrk, canvas_pos)) {
+                    r.push_back(&mrk);
+                }
+            }
+        }
+    }
+    return r;
+}
+
+
 MarkerRenderer::MarkerRenderer(const CanvasGL &c, Markers &ma) : ca(c), markers_ref(ma)
 {
 }
@@ -114,11 +145,10 @@ void MarkerRenderer::render()
 void MarkerRenderer::update()
 {
     markers.clear();
-    int i = 0;
     for (const auto &dom : markers_ref.domains) {
-        if (markers_ref.domains_visible.at(i)) {
-            for (const auto &mkr : dom) {
-                if (mkr.sheet == ca.markers.sheet_filter || mkr.sheet.size() == 0) {
+        if (dom.visible) {
+            for (const auto &mkr : dom.markers) {
+                if (ca.markers.marker_is_visible(mkr)) {
                     uint8_t flags = 0;
                     if (mkr.size == MarkerRef::Size::SMALL)
                         flags = 1;
@@ -126,8 +156,6 @@ void MarkerRenderer::update()
                 }
             }
         }
-
-        i++;
     }
 }
 
