@@ -4,6 +4,7 @@
 #include <glm/gtc/type_ptr.hpp>
 #include "bitmap_font_util.hpp"
 #include <range/v3/view.hpp>
+#include "common/layer_provider.hpp"
 
 namespace horizon {
 
@@ -146,7 +147,7 @@ void TriangleRenderer::realize()
 }
 
 
-class UBOBuffer {
+class UBOBufferTriangle {
 public:
     static constexpr size_t ubo_size = 23; //  keep in sync with ubo.glsl
     static_assert(static_cast<int>(ColorP::N_COLORS) == ubo_size, "ubo size mismatch");
@@ -225,7 +226,7 @@ void TriangleRenderer::render_layer_batch(int layer, HighlightMode highlight_mod
                                           bool use_stencil, bool stencil_mode)
 {
     const auto &ld = ca.get_layer_display(layer);
-    UBOBuffer buf;
+    UBOBufferTriangle buf;
 
     buf.alpha = ca.property_layer_opacity() / 100;
     gl_mat3_to_array(buf.screenmat, ca.screenmat);
@@ -299,7 +300,7 @@ void TriangleRenderer::render_layer_batch(int layer, HighlightMode highlight_mod
                 if (ca.appearance.colors.count(k))
                     buf.colors[i] = apply_highlight(ca.appearance.colors.at(k), highlight_mode, layer);
             }
-            auto lc = ca.get_layer_color(layer);
+            auto lc = ca.get_layer_color(ca.layer_provider.get_color_layer(layer));
             buf.colors[static_cast<int>(ColorP::AIRWIRE_ROUTER)] =
                     gl_array_from_color(ca.appearance.colors.at(ColorP::AIRWIRE_ROUTER));
             buf.colors[static_cast<int>(ColorP::FROM_LAYER)] = apply_highlight(lc, highlight_mode, layer);
@@ -369,7 +370,11 @@ void TriangleRenderer::render()
         if (ca.get_layer_display(it.first).visible)
             layers.push_back(it.first);
     }
-    std::sort(layers.begin(), layers.end());
+
+    std::sort(layers.begin(), layers.end(), [this](auto la, auto lb) {
+        return ca.layer_provider.get_layer_position(la) < ca.layer_provider.get_layer_position(lb);
+    });
+
     if (ca.work_layer < 0) {
         std::reverse(layers.begin(), layers.end());
     }
