@@ -105,15 +105,9 @@ private:
 
     Filenames filenames;
 
-    class HistoryItem : public Core::HistoryItem {
-    public:
-        HistoryItem(const Block &b, const Board &r, const std::string &comment);
-        Block block;
-        Board brd;
-    };
     void rebuild_internal(bool from_undo, const std::string &comment) override;
-    void history_push(const std::string &comment) override;
-    void history_load(unsigned int i) override;
+    std::unique_ptr<HistoryManager::HistoryItem> make_history_item(const std::string &comment) override;
+    void history_load(const HistoryManager::HistoryItem &it) override;
     void save(const std::string &suffix) override;
     void delete_autosave() override;
 };
