@@ -42,14 +42,9 @@ private:
 
     std::string m_decal_filename;
 
-    class HistoryItem : public Core::HistoryItem {
-    public:
-        HistoryItem(const Decal &r, const std::string &cm);
-        Decal decal;
-    };
     void rebuild_internal(bool from_undo, const std::string &comment) override;
-    void history_push(const std::string &comment) override;
-    void history_load(unsigned int i) override;
+    std::unique_ptr<HistoryManager::HistoryItem> make_history_item(const std::string &comment) override;
+    void history_load(const HistoryManager::HistoryItem &it) override;
     void save(const std::string &suffix) override;
     void delete_autosave() override;
 };
