@@ -175,16 +175,7 @@ bool Core::get_property(ObjectType type, const UUID &uu, ObjectProperty::ID prop
         case ObjectProperty::ID::USAGE: {
             std::string usage;
             if (poly->usage) {
-                auto ty = poly->usage->get_type();
-                if (ty == PolygonUsage::Type::PLANE) {
-                    usage = "Plane";
-                }
-                else if (ty == PolygonUsage::Type::KEEPOUT) {
-                    usage = "Keepout";
-                }
-                else {
-                    usage = "Invalid";
-                }
+                usage = object_descriptions.at(poly->usage->get_type()).name;
             }
             else {
                 usage = "None";
@@ -506,9 +497,7 @@ void Core::layers_to_meta(PropertyMeta &meta)
     PropertyMetaLayers &m = dynamic_cast<PropertyMetaLayers &>(meta);
     m.layers.clear();
     const auto &prv = get_layer_provider();
-    for (const auto &it : prv.get_layers()) {
-        m.layers.emplace(it.first, it.second);
-    }
+    m.layers = prv.get_layers_sorted(LayerProvider::LayerSortOrder::BOTTOM_TO_TOP);
     m.is_visible = prv.get_layers().size() > 1;
 }
 
