@@ -69,23 +69,21 @@ public:
     void add_sheet();
     void delete_sheet(const UUID &uu);
 
-    void set_sheet(const UUID &uu);
     const Sheet &get_canvas_data();
     const BlockSymbol &get_canvas_data_block_symbol();
     std::pair<Coordi, Coordi> get_bbox() override;
 
-    void set_block(const UUID &uu);
     const UUID &get_current_block_uuid() const;
     const UUID &get_top_block_uuid() const;
 
-    void set_block_symbol_mode();
+    void set_block_symbol_mode(const UUID &block);
     bool get_block_symbol_mode() const override;
 
     const BlocksSchematic &get_blocks() const;
     BlocksSchematic &get_blocks() override;
     bool current_block_is_top() const override;
 
-    void set_instance_path(const UUIDVec &path);
+    void set_instance_path(const UUID &sheet, const UUID &block, const UUIDVec &path);
     const UUIDVec &get_instance_path() const override;
     bool in_hierarchy() const override;
 
@@ -131,16 +129,9 @@ private:
 
     Filenames filenames;
 
-    class HistoryItem : public Core::HistoryItem {
-    public:
-        HistoryItem(const BlocksSchematic &bl, const std::string &cm) : Core::HistoryItem(cm), blocks(bl)
-        {
-        }
-        BlocksSchematic blocks;
-    };
     void rebuild_internal(bool from_undo, const std::string &comment) override;
-    void history_push(const std::string &comment) override;
-    void history_load(unsigned int i) override;
+    std::unique_ptr<HistoryManager::HistoryItem> make_history_item(const std::string &comment) override;
+    void history_load(const HistoryManager::HistoryItem &it) override;
     std::string get_history_comment_context() const override;
     void save(const std::string &suffix) override;
     void delete_autosave() override;
