@@ -56,6 +56,7 @@
 #include "tools/tool_generate_silkscreen.hpp"
 #include "tools/tool_set_group.hpp"
 #include "tools/tool_swap_nets.hpp"
+#include "tools/tool_swap_placement.hpp"
 #include "tools/tool_line_loop_to_polygon.hpp"
 #include "tools/tool_lines_to_tracks.hpp"
 #include "tools/tool_change_unit.hpp"
@@ -334,6 +335,9 @@ std::unique_ptr<ToolBase> Core::create_tool(ToolID tool_id)
     case ToolID::SWAP_NETS:
         return std::make_unique<ToolSwapNets>(this, tool_id);
 
+    case ToolID::SWAP_PLACEMENT:
+        return std::make_unique<ToolSwapPlacement>(this, tool_id);
+
     case ToolID::LINE_LOOP_TO_POLYGON:
         return std::make_unique<ToolLineLoopToPolygon>(this, tool_id);
 
