@@ -2,6 +2,5 @@
 #include "core/tool_data.hpp"
 
 namespace horizon {
-class ToolDataFromPlacePowerSymbol : public ToolData {
-};
+class ToolDataFromPlacePowerSymbol : public ToolData {};
 } // namespace horizon
