@@ -3,6 +3,7 @@
 #include "imp/imp_interface.hpp"
 #include "document/idocument.hpp"
 #include "util/selection_util.hpp"
+#include "util/geom_util.hpp"
 
 namespace horizon {
 
@@ -44,9 +45,20 @@ ToolResponse ToolDragPolygonEdge::begin(const ToolArgs &args)
     if (!poly)
         return ToolResponse::end();
 
-    selection = {{poly->uuid, ObjectType::POLYGON_EDGE, edge}};
     imp->set_snap_filter({{ObjectType::POLYGON, poly->uuid}});
-    poly_info.emplace(*poly, edge);
+    if (poly->vertices.size() == 2 && std::all_of(poly->vertices.begin(), poly->vertices.end(), [](auto &x) {
+            return x.type == Polygon::Vertex::Type::ARC;
+        })) {
+        circle_mode = true;
+        selection = {
+                {poly->uuid, ObjectType::POLYGON_VERTEX, 0},
+                {poly->uuid, ObjectType::POLYGON_VERTEX, 1},
+        };
+    }
+    else {
+        selection = {{poly->uuid, ObjectType::POLYGON_EDGE, edge}};
+        poly_info.emplace(*poly, edge);
+    }
     pos_orig = args.coords;
 
     plane_init(*poly);
@@ -59,11 +71,23 @@ ToolResponse ToolDragPolygonEdge::begin(const ToolArgs &args)
 ToolResponse ToolDragPolygonEdge::update(const ToolArgs &args)
 {
     if (args.type == ToolEventType::MOVE) {
-        const auto pos = poly_info->get_pos(args.coords - pos_orig);
-        poly->get_vertex(edge).position = pos.from;
-        poly->get_vertex(edge + 1).position = pos.to;
-        if (poly->get_vertex(edge).type == Polygon::Vertex::Type::ARC) {
-            poly->get_vertex(edge).arc_center = poly_info->arc_center_orig + pos.arc_center;
+        if (circle_mode) {
+            const auto c = project_onto_perp_bisector(poly->vertices.at(0).position, poly->vertices.at(1).position,
+                                                      poly->vertices.at(0).arc_center)
+                                   .to_coordi();
+            const auto v = args.coords - c;
+            poly->vertices.at(0).position = c + v;
+            poly->vertices.at(1).position = c - v;
+            poly->vertices.at(0).arc_center = c;
+            poly->vertices.at(1).arc_center = c;
+        }
+        else {
+            const auto pos = poly_info->get_pos(args.coords - pos_orig);
+            poly->get_vertex(edge).position = pos.from;
+            poly->get_vertex(edge + 1).position = pos.to;
+            if (poly->get_vertex(edge).type == Polygon::Vertex::Type::ARC) {
+                poly->get_vertex(edge).arc_center = poly_info->arc_center_orig + pos.arc_center;
+            }
         }
     }
     else if (args.type == ToolEventType::ACTION) {
@@ -74,8 +98,10 @@ ToolResponse ToolDragPolygonEdge::update(const ToolArgs &args)
             // fall through
 
         case InToolActionID::LMB:
-            plane_finish();
-            return ToolResponse::commit();
+            if (plane_finish())
+                return ToolResponse::commit();
+            else
+                return ToolResponse::revert();
 
         case InToolActionID::RMB:
         case InToolActionID::CANCEL:
