@@ -1,5 +1,6 @@
 #pragma once
 #include "core/tool.hpp"
+#include "tool_settings_rectangle_mode.hpp"
 
 namespace horizon {
 
@@ -10,15 +11,7 @@ public:
     ToolResponse update(const ToolArgs &args) override;
     bool can_begin() override;
 
-    class Settings : public ToolSettings {
-    public:
-        json serialize() const override;
-        void load_from_json(const json &j) override;
-        enum class Mode { CENTER, CORNER };
-        Mode mode = Mode::CENTER;
-    };
-
-    const ToolSettings *get_settings_const() const override
+    ToolSettings *get_settings() override
     {
         return &settings;
     }
@@ -40,14 +33,9 @@ public:
         };
     }
 
-protected:
-    ToolSettings *get_settings() override
-    {
-        return &settings;
-    }
-
 private:
-    Settings settings;
+    ToolSettingsRectangleMode settings;
+    using Mode = ToolSettingsRectangleMode::Mode;
 
     enum class Decoration { NONE, CHAMFER, NOTCH };
 
@@ -56,7 +44,7 @@ private:
     Coordi first_pos;
     Coordi second_pos;
     int step = 0;
-    uint64_t decoration_size = 1_mm;
+    uint64_t decoration_size = 1.2_mm;
     int64_t corner_radius = 0;
 
     class Polygon *temp = nullptr;
