@@ -25,7 +25,7 @@ public:
         int64_t line_width = .15_mm;
     };
 
-    const ToolSettings *get_settings_const() const override
+    ToolSettings *get_settings() override
     {
         return &settings;
     }
@@ -39,12 +39,6 @@ public:
         };
     }
 
-protected:
-    ToolSettings *get_settings() override
-    {
-        return &settings;
-    }
-
 private:
     bool select_polygon();
     ToolResponse redraw_silkscreen();
