@@ -13,18 +13,9 @@ public:
         uint64_t width = 0;
     };
 
-    const ToolSettings *get_settings_const() const override
-    {
-        return &settings;
-    }
-
-    ToolID get_tool_id_for_settings() const override;
+    std::map<ToolID, ToolSettings *> get_all_settings() override;
 
 protected:
-    ToolSettings *get_settings() override
-    {
-        return &settings;
-    }
     void ask_line_width();
 
     Settings settings;
