@@ -55,8 +55,8 @@ ToolResponse ToolSetViaNet::begin(const ToolArgs &args)
     }
 
     if (tool_id == ToolID::SET_VIA_NET) {
-        if (auto r = imp->dialogs.select_net(*doc.b->get_block(), false)) {
-            auto net = &doc.b->get_block()->nets.at(*r);
+        if (auto r = imp->dialogs.select_net(*doc.b->get_top_block(), false)) {
+            auto net = &doc.b->get_top_block()->nets.at(*r);
             nets.insert(net->uuid);
             for (auto via : vias)
                 via->net_set = net;
