@@ -16,7 +16,14 @@ private:
     void ok_clicked();
     void update_layers();
     void create_editors();
-    void create_editor(int layer, bool cu);
+    void create_editor(int layer);
+    Glib::RefPtr<Gtk::SizeGroup> sg_color_box;
     Glib::RefPtr<Gtk::SizeGroup> sg_layer_name;
+    Glib::RefPtr<Gtk::SizeGroup> sg_layer_grid;
+    Glib::RefPtr<Gtk::SizeGroup> sg_layer_move;
+    Glib::RefPtr<Gtk::SizeGroup> sg_layer_add;
+    Glib::RefPtr<Gtk::SizeGroup> sg_layer_delete;
+    Glib::RefPtr<Gtk::SizeGroup> sg_adj;
+    void reload();
 };
 } // namespace horizon
