@@ -1,6 +1,7 @@
 #pragma once
 #include "gerber_writer.hpp"
 #include "excellon_writer.hpp"
+#include "util/layer_range.hpp"
 #include <memory>
 #include <sstream>
 
@@ -18,11 +19,14 @@ private:
     const class GerberOutputSettings &settings;
     std::map<int, GerberWriter> writers;
     GerberWriter *get_writer_for_layer(int l);
-    ExcellonWriter *get_drill_writer(bool pth);
+    ExcellonWriter *get_drill_writer(const LayerRange &span, bool pth);
     std::unique_ptr<ExcellonWriter> drill_writer_pth;
     std::unique_ptr<ExcellonWriter> drill_writer_npth;
+    std::map<LayerRange, ExcellonWriter> drill_writers_blind_buried;
     std::stringstream log;
 
+    std::vector<ExcellonWriter *> get_drill_writers();
+
     void generate_zip();
 };
 } // namespace horizon
