@@ -5,7 +5,8 @@
 
 namespace horizon {
 class LayerRange;
-}
+class LayerProvider;
+} // namespace horizon
 namespace horizon::ODB {
 
 extern const char *endl;
@@ -54,8 +55,8 @@ std::ostream &operator<<(std::ostream &os, DimUm d);
 std::string utf8_to_ascii(const std::string &s);
 std::string make_legal_name(const std::string &n);
 std::string make_legal_entity_name(const std::string &s);
-std::string get_layer_name(int id);
-std::string get_drills_layer_name(const LayerRange &span);
+std::string get_layer_name(int id, const LayerProvider &lprv);
+std::string get_drills_layer_name(const LayerRange &span, const LayerProvider &lprv);
 
 std::string make_symbol_circle(uint64_t diameter);
 std::string make_symbol_rect(uint64_t w, uint64_t h);
