@@ -5,13 +5,14 @@
 namespace horizon {
 class Padstack;
 class TreeWriter;
+class LayerProvider;
 } // namespace horizon
 
 namespace horizon::ODB {
 
 class Symbol {
 public:
-    Symbol(const Padstack &ps, int layer);
+    Symbol(const Padstack &ps, int layer, const LayerProvider &lprv);
 
     std::string name;
     Features features;
