@@ -6,16 +6,22 @@
 #include "common/hole.hpp"
 #include "canvas/appearance.hpp"
 #include "board/plane.hpp"
+#include <sstream>
 
 namespace horizon {
 
+double to_pt(double x_nm)
+{
+    return x_nm * .000002834645669291339;
+}
 
-CanvasPDF::CanvasPDF(PoDoFo::PdfPainterMM &p, PoDoFo::PdfFont &f, const PDFExportSettings &s)
-    : Canvas::Canvas(), painter(p), font(f), settings(s), metrics(font.GetFontMetrics())
+CanvasPDF::CanvasPDF(PoDoFo::PdfPainter &p, PoDoFo::PdfFont &f, const PDFExportSettings &s)
+    : Canvas::Canvas(), painter(p), font(f), settings(s), metrics(font.GetMetrics())
 {
     img_mode = true;
     Appearance apperarance;
     layer_colors = apperarance.layer_colors;
+    path.Reset();
 }
 
 bool CanvasPDF::pdf_layer_visible(int l) const
@@ -38,9 +44,9 @@ void CanvasPDF::img_line(const Coordi &p0, const Coordi &p1, const uint64_t widt
 {
     if (!pdf_layer_visible(layer))
         return;
-    painter.Save();
-    auto w = std::max(width, settings.min_line_width);
-    painter.SetStrokeWidthMM(to_um(w));
+
+    auto w = std::max(width, std::max(settings.min_line_width, (uint64_t).001_mm));
+    painter.GraphicsState.SetLineWidth(to_pt(w));
     Coordi rp0 = p0;
     Coordi rp1 = p1;
     if (tr) {
@@ -48,9 +54,8 @@ void CanvasPDF::img_line(const Coordi &p0, const Coordi &p1, const uint64_t widt
         rp1 = transform.transform(p1);
     }
     auto color = get_pdf_layer_color(layer);
-    painter.SetStrokingColor(color.r, color.g, color.b);
-    painter.DrawLineMM(to_um(rp0.x), to_um(rp0.y), to_um(rp1.x), to_um(rp1.y));
-    painter.Restore();
+    painter.GraphicsState.SetStrokeColor(PoDoFo::PdfColor(color.r, color.g, color.b));
+    painter.DrawLine(to_pt(rp0.x), to_pt(rp0.y), to_pt(rp1.x), to_pt(rp1.y));
 }
 
 void CanvasPDF::img_draw_text(const Coordf &p, float size, const std::string &rtext, int angle, bool flip,
@@ -83,10 +88,11 @@ void CanvasPDF::img_draw_text(const Coordf &p, float size, const std::string &rt
     if (mirror) {
         lineskip *= -1;
     }
-    font.SetFontSize(to_pt(size) * 1.6);
+
+    painter.TextState.SetFont(font, to_pt(size) * 1.6);
     while (std::getline(ss, line, '\n')) {
         line = TextData::trim(line);
-        int64_t line_width = metrics->StringWidthMM(line.c_str()) * 1000;
+        int64_t line_width = font.GetStringLength(line.c_str(), painter.TextState);
 
         Placement tf;
         tf.shift.x = p.x;
@@ -124,9 +130,9 @@ void CanvasPDF::img_draw_text(const Coordf &p, float size, const std::string &rt
         Coordi p0(xshift, yshift);
         Coordi pt = tf.transform(p0);
 
-        painter.SetTransformationMatrix(cos(fangle), sin(fangle), -sin(fangle), cos(fangle), to_pt(pt.x), to_pt(pt.y));
-        PoDoFo::PdfString pstr(reinterpret_cast<const PoDoFo::pdf_utf8 *>(line.c_str()));
-        painter.DrawTextMM(0, to_um(size) / -2, pstr);
+        painter.GraphicsState.SetCurrentMatrix(PoDoFo::Matrix::FromCoefficients(cos(fangle), sin(fangle), -sin(fangle),
+                                                                                cos(fangle), to_pt(pt.x), to_pt(pt.y)));
+        painter.DrawText(line.c_str(), 0, to_pt(size) / -2);
         painter.Restore();
 
         i_line++;
@@ -135,55 +141,55 @@ void CanvasPDF::img_draw_text(const Coordf &p, float size, const std::string &rt
 
 void CanvasPDF::img_polygon(const Polygon &ipoly, bool tr)
 {
+
     if (!pdf_layer_visible(ipoly.layer))
         return;
-    painter.Save();
+
     auto color = get_pdf_layer_color(ipoly.layer);
-    painter.SetColor(color.r, color.g, color.b);
-    painter.SetStrokingColor(color.r, color.g, color.b);
-    painter.SetStrokeWidthMM(to_um(settings.min_line_width));
+    painter.GraphicsState.SetFillColor(PoDoFo::PdfColor(color.r, color.g, color.b));
+    painter.GraphicsState.SetStrokeColor(PoDoFo::PdfColor(color.r, color.g, color.b));
+    painter.GraphicsState.SetLineWidth(to_pt(settings.min_line_width));
     if (ipoly.usage == nullptr) { // regular patch
         draw_polygon(ipoly, tr);
         if (fill)
-            painter.Fill();
+            painter.DrawPath(path, PoDoFo::PdfPathDrawMode::Fill);
         else
-            painter.Stroke();
+            painter.DrawPath(path, PoDoFo::PdfPathDrawMode::Stroke);
     }
     else if (auto plane = dynamic_cast<const Plane *>(ipoly.usage.ptr)) {
         for (const auto &frag : plane->fragments) {
-            for (const auto &path : frag.paths) {
+            for (const auto &dpath : frag.paths) {
                 bool first = true;
-                for (const auto &it : path) {
+                for (const auto &it : dpath) {
                     Coordi p(it.X, it.Y);
                     if (tr)
                         p = transform.transform(p);
                     if (first)
-                        painter.MoveToMM(to_um(p.x), to_um(p.y));
+                        path.MoveTo(to_pt(p.x), to_pt(p.y));
                     else
-                        painter.LineToMM(to_um(p.x), to_um(p.y));
+                        path.AddLineTo(to_pt(p.x), to_pt(p.y));
                     first = false;
                 }
+                path.Close();
             }
-            painter.ClosePath();
         }
         if (fill)
-            painter.Fill(true);
+            painter.DrawPath(path, PoDoFo::PdfPathDrawMode::Fill);
         else
-            painter.Stroke();
+            painter.DrawPath(path, PoDoFo::PdfPathDrawMode::Stroke);
     }
-    painter.Restore();
+    path.Reset();
 }
 
 void CanvasPDF::img_hole(const Hole &hole)
 {
     if (!pdf_layer_visible(PDFExportSettings::HOLES_LAYER))
         return;
-    painter.Save();
 
     auto color = get_pdf_layer_color(PDFExportSettings::HOLES_LAYER);
-    painter.SetColor(color.r, color.g, color.b);
-    painter.SetStrokingColor(color.r, color.g, color.b);
-    painter.SetStrokeWidthMM(to_um(settings.min_line_width));
+    painter.GraphicsState.SetFillColor(PoDoFo::PdfColor(color.r, color.g, color.b));
+    painter.GraphicsState.SetStrokeColor(PoDoFo::PdfColor(color.r, color.g, color.b));
+    painter.GraphicsState.SetLineWidth(to_pt(settings.min_line_width));
 
     auto hole2 = hole;
     if (settings.set_holes_size) {
@@ -191,18 +197,18 @@ void CanvasPDF::img_hole(const Hole &hole)
     }
     draw_polygon(hole2.to_polygon(), true);
     if (fill)
-        painter.Fill(true);
+        painter.DrawPath(path, PoDoFo::PdfPathDrawMode::Fill);
     else
-        painter.Stroke();
-    painter.Restore();
+        painter.DrawPath(path, PoDoFo::PdfPathDrawMode::Stroke);
+    path.Reset();
 }
 
 // c is the arc center.
-// angles must be in radians, c and r must be in a PDF "pt" unit.
+// angles must be in radians, c and r must be in mm.
 // See "How to determine the control points of a Bézier curve that approximates a
 // small circular arc" by Richard ADeVeneza, Nov 2004
 // https://www.tinaja.com/glib/bezcirc2.pdf
-static Coordd pdf_arc_segment(PoDoFo::PdfPainter &painter, const Coordd c, const double r, double a0, double a1)
+static Coordd pdf_arc_segment(PoDoFo::PdfPainterPath &path, const Coordd c, const double r, double a0, double a1)
 {
     const auto da = a0 - a1;
     assert(da != 0);
@@ -223,18 +229,17 @@ static Coordd pdf_arc_segment(PoDoFo::PdfPainter &painter, const Coordd c, const
     const auto c2 = p2.rotate(theta) * r + c;
     const auto c3 = p3.rotate(theta) * r + c;
 
-    painter.CubicBezierTo(c1.x, c1.y, c2.x, c2.y, c3.x, c3.y);
+    path.AddCubicBezierTo(to_pt(c1.x), to_pt(c1.y), to_pt(c2.x), to_pt(c2.y), to_pt(c3.x), to_pt(c3.y));
     return c3; // end point
 }
 
-static void pdf_arc(PoDoFo::PdfPainter &painter, const Coordd start, const Coordd c, const Coordd end, bool cw)
+static void pdf_arc(PoDoFo::PdfPainterPath &path, const Coordd start, const Coordd c, const Coordd end, bool cw)
 {
-    const auto r = to_pt((start - c).mag());
-    const auto ctr = Coordd(to_pt(c.x), to_pt(c.y));
+    const auto r = (start - c).mag();
 
     // Get angles relative to the x axis
-    double a0 = atan2(start.y - c.y, start.x - c.x);
-    double a1 = atan2(end.y - c.y, end.x - c.x);
+    double a0 = (start - c).angle();
+    double a1 = (end - c).angle();
 
     // Circle or large arc
     if (cw && a0 <= a1) {
@@ -252,10 +257,10 @@ static void pdf_arc(PoDoFo::PdfPainter &painter, const Coordd start, const Coord
         assert(a0 < a1);
     }
     double e = a1 - a0;
-    while (std::abs(e) > 0) {
+    while (std::abs(e) > 1e-6) {
         const auto d = (cw) ? std::max(e, da) : std::min(e, da);
         const auto a = a0 + d;
-        pdf_arc_segment(painter, ctr, r, a0, a);
+        pdf_arc_segment(path, c, r, a0, a);
         a0 = a;
         e = a1 - a0;
     }
@@ -275,28 +280,29 @@ void CanvasPDF::draw_polygon(const Polygon &ipoly, bool tr)
             it_next = ipoly.vertices.cbegin();
         }
         if (first) {
-            painter.MoveToMM(to_um(p.x), to_um(p.y));
+            path.MoveTo(to_pt(p.x), to_pt(p.y));
         }
         if (it->type == Polygon::Vertex::Type::LINE) {
-            if (!first)
-                painter.LineToMM(to_um(p.x), to_um(p.y));
+            if (!first) {
+                path.AddLineTo(to_pt(p.x), to_pt(p.y));
+            }
         }
         else if (it->type == Polygon::Vertex::Type::ARC) {
             Coordd end = it_next->position;
-            Coordd c = it->arc_center;
+            Coordd c = project_onto_perp_bisector(end, it->position, it->arc_center);
             if (!first)
-                painter.LineToMM(to_um(p.x), to_um(p.y));
+                path.AddLineTo(to_pt(p.x), to_pt(p.y));
 
             if (tr) {
                 c = transform.transform(c);
                 end = transform.transform(end);
             }
-            pdf_arc(painter, p, c, end, it->arc_reverse);
+            pdf_arc(path, p, c, end, it->arc_reverse);
         }
         first = false;
     }
 
-    painter.ClosePath();
+    path.Close();
 }
 
 void CanvasPDF::request_push()
