@@ -1,12 +1,13 @@
 #include "export_pdf.hpp"
 #include "canvas_pdf.hpp"
-#include <podofo/podofo.h>
+#include "util/podofo_inc.hpp"
 #include "util/util.hpp"
 #include "schematic/schematic.hpp"
 #include "export_pdf_util.hpp"
 #include "schematic/iinstancce_mapping_provider.hpp"
 #include "util/bbox_accumulator.hpp"
 #include "pool/part.hpp"
+#include <giomm.h>
 
 namespace horizon {
 
@@ -53,17 +54,13 @@ private:
     UUIDVec instance_path;
 };
 
-#if PODOFO_VERSION_MAJOR != 0 || PODOFO_VERSION_MINOR != 9 || PODOFO_VERSION_PATCH != 5
-#define HAVE_OUTLINE
-#endif
-
 using Callback = std::function<void(std::string, double)>;
 
 class PDFExporter {
 public:
     PDFExporter(const class PDFExportSettings &settings, Callback callback)
-        : document(settings.output_filename.c_str()), font(document.CreateFont("Helvetica")),
-          canvas(painter, *font, settings), cb(callback)
+        : document(), font(load_font(document)), canvas(painter, font, settings), cb(callback),
+          filename(settings.output_filename.c_str())
     {
         canvas.use_layer_colors = false;
     }
@@ -71,55 +68,54 @@ public:
     void export_pdf(const class Schematic &sch)
     {
         cb("Initializing", 0);
-        auto info = document.GetInfo();
-        info->SetCreator("Horizon EDA");
-        info->SetProducer("Horizon EDA");
+        document.GetMetadata().SetCreator(PoDoFo::PdfString("Horizon EDA"));
+        document.GetMetadata().SetProducer(PoDoFo::PdfString("Horizon EDA"));
         if (sch.block->project_meta.count("author")) {
-            info->SetAuthor(sch.block->project_meta.at("author"));
+            document.GetMetadata().SetAuthor(PoDoFo::PdfString(sch.block->project_meta.at("author")));
         }
         std::string title = "Schematic";
         if (sch.block->project_meta.count("project_title")) {
             title = sch.block->project_meta.at("project_title");
         }
-        info->SetTitle(title);
+        document.GetMetadata().SetTitle(PoDoFo::PdfString(title));
         MyInstanceMappingProvider prv(sch);
 
-#ifdef HAVE_OUTLINE
-        outlines = document.GetOutlines();
-        PoDoFo::PdfOutlineItem *proot = nullptr;
-#else
-        PoDoFo::PdfOutlineItem *proot = nullptr;
-#endif
+        outlines = &document.GetOrCreateOutlines();
+
+        export_schematic(sch, {}, prv, nullptr);
 
-        export_schematic(sch, {}, prv, proot);
         for (auto &[path, number, rect] : annotations) {
-            auto page = document.GetPage(number);
-            auto annot = page->CreateAnnotation(PoDoFo::ePdfAnnotation_Link, rect);
-            annot->SetBorderStyle(0, 0, 0);
-            annot->SetDestination(first_pages.at(path));
+            auto &page = document.GetPages().GetPageAt(number);
+            auto &annot = page.GetAnnotations().CreateAnnot<PoDoFo::PdfAnnotationLink>(rect);
+            annot.SetBorderStyle(0, 0, 0);
+            annot.SetDestination(first_pages.at(path));
         }
         for (auto &[url, number, rect] : datasheet_annotations) {
-            auto page = document.GetPage(number);
-            auto annot = page->CreateAnnotation(PoDoFo::ePdfAnnotation_Link, rect);
-            annot->SetBorderStyle(0, 0, 0);
+            auto &page = document.GetPages().GetPageAt(number);
+            auto &annot = page.GetAnnotations().CreateAnnot<PoDoFo::PdfAnnotationLink>(rect);
+            annot.SetBorderStyle(0, 0, 0);
 
-            PoDoFo::PdfAction action(PoDoFo::ePdfAction_URI, &document);
-            action.SetURI(PoDoFo::PdfString(url));
-            annot->SetAction(action);
+            auto action = std::make_shared<PoDoFo::PdfAction>(document, PoDoFo::PdfActionType::URI);
+
+            action->SetURI(PoDoFo::PdfString(url));
+            annot.SetAction(action);
         }
-        document.Close();
+
+        document.Save(filename);
     }
 
 private:
-    PoDoFo::PdfStreamedDocument document;
+    PoDoFo::PdfMemDocument document;
     PoDoFo::PdfPainter painter;
-    PoDoFo::PdfFont *font = nullptr;
-    std::map<UUIDVec, PoDoFo::PdfDestination> first_pages;
-    std::vector<std::tuple<UUIDVec, unsigned int, PoDoFo::PdfRect>> annotations;
-    std::vector<std::tuple<std::string, unsigned int, PoDoFo::PdfRect>> datasheet_annotations;
+    PoDoFo::PdfFont &font;
     PoDoFo::PdfOutlines *outlines = nullptr;
+    std::map<UUIDVec, std::shared_ptr<PoDoFo::PdfDestination>> first_pages;
+    std::vector<std::tuple<UUIDVec, unsigned int, PoDoFo::Rect>> annotations;
+    std::vector<std::tuple<std::string, unsigned int, PoDoFo::Rect>> datasheet_annotations;
+
     CanvasPDF canvas;
     Callback cb;
+    std::basic_string_view<char> filename;
 
     void export_schematic(const Schematic &sch, const UUIDVec &path, MyInstanceMappingProvider &prv,
                           PoDoFo::PdfOutlineItem *parent)
@@ -129,24 +125,28 @@ private:
         prv.set_instance_path(path);
         Schematic my_sch = sch;
         my_sch.expand(false, &prv);
-        bool first = true;
         auto sheets = my_sch.get_sheets_sorted();
+        bool first = true;
+
         for (const auto sheet : sheets) {
+
             const auto idx = prv.get_sheet_index_for_path(sheet->uuid, path);
             const auto progress = (double)idx / prv.get_sheet_total();
             cb("Exporting sheet " + format_m_of_n(idx, prv.get_sheet_total()), progress);
-            auto page =
-                    document.CreatePage(PoDoFo::PdfRect(0, 0, to_pt(sheet->frame.width), to_pt(sheet->frame.height)));
-            painter.SetPage(page);
-            painter.SetLineCapStyle(PoDoFo::ePdfLineCapStyle_Round);
-            painter.SetFont(font);
-            painter.SetColor(0, 0, 0);
-            painter.SetTextRenderingMode(PoDoFo::ePdfTextRenderingMode_Invisible);
+            auto &page = document.GetPages().CreatePage(
+                    PoDoFo::Rect(0, 0, to_pt(sheet->frame.width), to_pt(sheet->frame.height)));
+            painter.SetCanvas(page);
+
+            painter.GraphicsState.SetLineCapStyle(PoDoFo::PdfLineCapStyle::Round);
+            painter.GraphicsState.SetFillColor(PoDoFo::PdfColor(0, 0, 0));
+            painter.TextState.SetFont(font, 10);
+            painter.TextState.SetRenderingMode(PoDoFo::PdfTextRenderingMode::Invisible);
 
             for (const auto &[uu, pic] : sheet->pictures) {
                 if (!pic.on_top)
                     render_picture(document, painter, pic);
             }
+
             for (const auto &[uu_sym, sym] : sheet->block_symbols) {
                 for (const auto &[uu, pic] : sym.symbol.pictures) {
                     if (!pic.on_top)
@@ -167,7 +167,7 @@ private:
                 }
             }
 
-            auto dest = PoDoFo::PdfDestination(page);
+            auto dest = std::make_shared<PoDoFo::PdfDestination>(page);
             if (first) {
                 first_pages.emplace(path, dest);
                 first = false;
@@ -187,10 +187,10 @@ private:
                                 acc.accumulate(c);
                             }
                             const auto [a, b] = acc.get();
-                            PoDoFo::PdfRect rect(to_pt(a.x), to_pt(a.y), to_pt(b.x - a.x), to_pt(b.y - a.y));
+                            PoDoFo::Rect rect(to_pt(a.x), to_pt(a.y), to_pt(b.x - a.x), to_pt(b.y - a.y));
                             annotations.emplace_back(
                                     uuid_vec_append(path, sheet->block_symbols.at(ir.uuid).block_instance->uuid),
-                                    page->GetPageNumber() - 1, rect);
+                                    page.GetPageNumber() - 1, rect);
                         }
                     }
                     else if (ir.type == ObjectType::SCHEMATIC_SYMBOL) {
@@ -203,35 +203,29 @@ private:
                                     acc.accumulate(c);
                                 }
                                 const auto [a, b] = acc.get();
-                                PoDoFo::PdfRect rect(to_pt(a.x), to_pt(a.y), to_pt(b.x - a.x), to_pt(b.y - a.y));
+                                PoDoFo::Rect rect(to_pt(a.x), to_pt(a.y), to_pt(b.x - a.x), to_pt(b.y - a.y));
                                 datasheet_annotations.emplace_back(sym.component->part->get_datasheet(),
-                                                                   page->GetPageNumber() - 1, rect);
+                                                                   page.GetPageNumber() - 1, rect);
                             }
                         }
                     }
                 }
             }
 
-            painter.FinishPage();
+            painter.FinishDrawing();
 
-#ifdef HAVE_OUTLINE
             PoDoFo::PdfOutlineItem *sheet_node;
             if (parent) {
-                sheet_node = parent->CreateChild(sheet->name, dest);
+                sheet_node = parent->CreateChild(PoDoFo::PdfString(sheet->name), dest);
             }
             else {
-                sheet_node = outlines->CreateRoot(sheet->name);
+                sheet_node = outlines->CreateRoot(PoDoFo::PdfString(sheet->name));
                 sheet_node->SetDestination(dest);
             }
-#endif
 
             for (auto sym : sheet->get_block_symbols_sorted()) {
-#ifdef HAVE_OUTLINE
-                auto sym_node = sheet_node->CreateChild(sym->block_instance->refdes, dest);
-                sym_node->SetTextFormat(PoDoFo::ePdfOutlineFormat_Italic);
-#else
-                PoDoFo::PdfOutlineItem *sym_node = nullptr;
-#endif
+                auto sym_node = sheet_node->CreateChild(PoDoFo::PdfString(sym->block_instance->refdes), dest);
+                sym_node->SetTextFormat(PoDoFo::PdfOutlineFormat::Italic);
                 export_schematic(*sym->schematic, uuid_vec_append(path, sym->block_instance->uuid), prv, sym_node);
             }
         }
