@@ -133,6 +133,30 @@ const std::map<ActionToolID, ActionCatalogItem> action_catalog = {
          {"Selection qualifier touch box", ActionGroup::SELECTION, ActionCatalogItem::AVAILABLE_EVERYWHERE,
           ActionCatalogItem::FLAGS_DEFAULT}},
 
+        {{ActionID::SELECTION_MODIFIER_ACTION_TOGGLE, ToolID::NONE},
+         {"Selection modifier action toggle", ActionGroup::SELECTION, ActionCatalogItem::AVAILABLE_EVERYWHERE,
+          ActionCatalogItem::FLAGS_DEFAULT}},
+
+        {{ActionID::SELECTION_MODIFIER_ACTION_ADD, ToolID::NONE},
+         {"Selection modifier action add", ActionGroup::SELECTION, ActionCatalogItem::AVAILABLE_EVERYWHERE,
+          ActionCatalogItem::FLAGS_DEFAULT}},
+
+        {{ActionID::SELECTION_MODIFIER_ACTION_REMOVE, ToolID::NONE},
+         {"Selection modifier action remove", ActionGroup::SELECTION, ActionCatalogItem::AVAILABLE_EVERYWHERE,
+          ActionCatalogItem::FLAGS_DEFAULT}},
+
+        {{ActionID::SELECTION_STICKY, ToolID::NONE},
+         {"Toggle sticky selection", ActionGroup::SELECTION, ActionCatalogItem::AVAILABLE_EVERYWHERE,
+          ActionCatalogItem::FLAGS_DEFAULT}},
+
+        {{ActionID::UNDO_SELECTION, ToolID::NONE},
+         {"Undo selection", ActionGroup::SELECTION, ActionCatalogItem::AVAILABLE_EVERYWHERE,
+          ActionCatalogItem::FLAGS_DEFAULT}},
+
+        {{ActionID::REDO_SELECTION, ToolID::NONE},
+         {"Redo selection", ActionGroup::SELECTION, ActionCatalogItem::AVAILABLE_EVERYWHERE,
+          ActionCatalogItem::FLAGS_DEFAULT}},
+
         {{ActionID::TO_BOARD, ToolID::NONE},
          {"Place on board", ActionGroup::SCHEMATIC, ActionCatalogItem::AVAILABLE_IN_SCHEMATIC,
           ActionCatalogItem::FLAGS_SPECIFIC}},
@@ -631,6 +655,10 @@ const std::map<ActionToolID, ActionCatalogItem> action_catalog = {
          {"Swap nets", ActionGroup::SCHEMATIC, ActionCatalogItem::AVAILABLE_IN_SCHEMATIC,
           ActionCatalogItem::FLAGS_DEFAULT}},
 
+        {{ActionID::TOOL, ToolID::SWAP_PLACEMENT},
+         {"Swap placement", ActionGroup::BOARD, ActionCatalogItem::AVAILABLE_IN_BOARD,
+          ActionCatalogItem::FLAGS_DEFAULT}},
+
         {{ActionID::TOOL, ToolID::LINE_LOOP_TO_POLYGON},
          {"Line loop to polygon", ActionGroup::GRAPHICS, ActionCatalogItem::AVAILABLE_EVERYWHERE,
           ActionCatalogItem::FLAGS_DEFAULT}},
@@ -1185,6 +1213,12 @@ const LutEnumStr<ActionID> action_lut = {
         ACTION_LUT_ITEM(SELECTION_QUALIFIER_INCLUDE_ORIGIN),
         ACTION_LUT_ITEM(SELECTION_QUALIFIER_TOUCH_BOX),
         ACTION_LUT_ITEM(SELECTION_QUALIFIER_INCLUDE_BOX),
+        ACTION_LUT_ITEM(SELECTION_MODIFIER_ACTION_TOGGLE),
+        ACTION_LUT_ITEM(SELECTION_MODIFIER_ACTION_ADD),
+        ACTION_LUT_ITEM(SELECTION_MODIFIER_ACTION_REMOVE),
+        ACTION_LUT_ITEM(SELECTION_STICKY),
+        ACTION_LUT_ITEM(UNDO_SELECTION),
+        ACTION_LUT_ITEM(REDO_SELECTION),
         ACTION_LUT_ITEM(TO_BOARD),
         ACTION_LUT_ITEM(MOVE_TO_OTHER_SHEET),
         ACTION_LUT_ITEM(SHOW_IN_BROWSER),
@@ -1387,6 +1421,7 @@ const LutEnumStr<ToolID> tool_lut = {
         TOOL_LUT_ITEM(MOVE_KEY_FINE_LEFT),
         TOOL_LUT_ITEM(MOVE_KEY_FINE_RIGHT),
         TOOL_LUT_ITEM(SWAP_NETS),
+        TOOL_LUT_ITEM(SWAP_PLACEMENT),
         TOOL_LUT_ITEM(LINE_LOOP_TO_POLYGON),
         TOOL_LUT_ITEM(LINES_TO_TRACKS),
         TOOL_LUT_ITEM(SCALE),
