@@ -157,8 +157,10 @@ json ImpBase::send_json(const json &j)
     }
     if (!sockets_connected)
         return nullptr;
-
-    std::string s = j.dump();
+    json j2 = j;
+    if (!j2.contains("token"))
+        j2["token"] = get_activation_token(main_window);
+    std::string s = j2.dump();
     const std::string op = j.value("op", "unknown");
     zmq::message_t msg(UUID::size + s.size() + 1);
     auto m = (char *)msg.data();
@@ -299,6 +301,23 @@ void ImpBase::update_selection_label()
         la += "auto";
         break;
     }
+
+    la += ", ";
+    switch (canvas->selection_modifier_action) {
+    case CanvasGL::SelectionModifierAction::TOGGLE:
+        la += "toggle";
+        break;
+    case CanvasGL::SelectionModifierAction::ADD:
+        la += "add";
+        break;
+    case CanvasGL::SelectionModifierAction::REMOVE:
+        la += "remove";
+        break;
+    }
+
+    if (canvas->selection_sticky)
+        la += ", sticky";
+
     la += ")";
     main_window->selection_label->set_text(la);
 }
@@ -376,6 +395,9 @@ void ImpBase::run(int argc, char *argv[])
         Gtk::RadioButton *selection_tool_box_button, *selection_tool_lasso_button, *selection_tool_paint_button;
         Gtk::RadioButton *selection_qualifier_include_origin_button, *selection_qualifier_touch_box_button,
                 *selection_qualifier_include_box_button, *selection_qualifier_auto_button;
+        Gtk::RadioButton *selection_modifier_action_toggle_button, *selection_modifier_action_add_button,
+                *selection_modifier_action_remove_button;
+        Gtk::CheckButton *sticky_selection_checkbutton;
         GET_WIDGET(selection_tool_box_button);
         GET_WIDGET(selection_tool_lasso_button);
         GET_WIDGET(selection_tool_paint_button);
@@ -383,6 +405,10 @@ void ImpBase::run(int argc, char *argv[])
         GET_WIDGET(selection_qualifier_touch_box_button);
         GET_WIDGET(selection_qualifier_include_box_button);
         GET_WIDGET(selection_qualifier_auto_button);
+        GET_WIDGET(selection_modifier_action_toggle_button);
+        GET_WIDGET(selection_modifier_action_add_button);
+        GET_WIDGET(selection_modifier_action_remove_button);
+        GET_WIDGET(sticky_selection_checkbutton);
 
         Gtk::Box *selection_qualifier_box;
         GET_WIDGET(selection_qualifier_box);
@@ -412,6 +438,18 @@ void ImpBase::run(int argc, char *argv[])
                     qual_map.at(qual)->set_active(true);
                 });
 
+        std::map<CanvasGL::SelectionModifierAction, Gtk::RadioButton *> mod_map = {
+                {CanvasGL::SelectionModifierAction::TOGGLE, selection_modifier_action_toggle_button},
+                {CanvasGL::SelectionModifierAction::ADD, selection_modifier_action_add_button},
+                {CanvasGL::SelectionModifierAction::REMOVE, selection_modifier_action_remove_button},
+        };
+        bind_widget<CanvasGL::SelectionModifierAction>(mod_map, canvas->selection_modifier_action,
+                                                       [this, mod_map](auto v) { this->update_selection_label(); });
+
+
+        bind_widget(sticky_selection_checkbutton, canvas->selection_sticky);
+        sticky_selection_checkbutton->signal_toggled().connect([this] { update_selection_label(); });
+
         connect_action(ActionID::SELECTION_TOOL_BOX,
                        [selection_tool_box_button](const auto &a) { selection_tool_box_button->set_active(true); });
 
@@ -443,6 +481,23 @@ void ImpBase::run(int argc, char *argv[])
         });
 
 
+        connect_action(ActionID::SELECTION_MODIFIER_ACTION_TOGGLE,
+                       [selection_modifier_action_toggle_button](const auto &a) {
+                           selection_modifier_action_toggle_button->set_active(true);
+                       });
+        connect_action(ActionID::SELECTION_MODIFIER_ACTION_ADD, [selection_modifier_action_add_button](const auto &a) {
+            selection_modifier_action_add_button->set_active(true);
+        });
+        connect_action(ActionID::SELECTION_MODIFIER_ACTION_REMOVE,
+                       [selection_modifier_action_remove_button](const auto &a) {
+                           selection_modifier_action_remove_button->set_active(true);
+                       });
+
+        connect_action(ActionID::SELECTION_STICKY, [sticky_selection_checkbutton](const auto &a) {
+            sticky_selection_checkbutton->set_active(!sticky_selection_checkbutton->get_active());
+        });
+
+
         update_selection_label();
     }
 
@@ -567,6 +622,17 @@ void ImpBase::run(int argc, char *argv[])
         this->update_property_panels();
     });
 
+    connect_action_with_source(ActionID::UNDO_SELECTION, [this](const auto &a, auto src) {
+        if (src == ActionSource::KEY && preferences.undo_redo.show_hints)
+            main_window->set_undo_redo_hint("Undid selection");
+        selection_undo();
+    });
+    connect_action_with_source(ActionID::REDO_SELECTION, [this](const auto &a, auto src) {
+        if (src == ActionSource::KEY && preferences.undo_redo.show_hints)
+            main_window->set_undo_redo_hint("Redid selection");
+        selection_redo();
+    });
+
     connect_action(ActionID::RELOAD_POOL, [this](const auto &a) {
         core->reload_pool();
         this->canvas_update_from_pp();
@@ -722,11 +788,19 @@ void ImpBase::run(int argc, char *argv[])
         main_window->header->pack_start(*undo_redo_box);
     }
 
+    attach_action_button(*main_window->undo_selection_button, ActionID::UNDO_SELECTION);
+    attach_action_button(*main_window->redo_selection_button, ActionID::REDO_SELECTION);
+
+    selection_history_manager.set_history_max(1000);
+
     core->signal_can_undo_redo().connect([this] {
         undo_button->set_tooltip_text(append_if_not_empty("Undo", core->get_undo_comment()));
         redo_button->set_tooltip_text(append_if_not_empty("Redo", core->get_redo_comment()));
         update_action_sensitivity();
     });
+
+    selection_history_manager.signal_changed().connect([this] { update_action_sensitivity(); });
+
     canvas->signal_selection_changed().connect([this] {
         if (!core->tool_is_active()) {
             update_action_sensitivity();
@@ -1120,6 +1194,7 @@ void ImpBase::apply_preferences()
     main_window->tool_bar_set_vertical(preferences.tool_bar.vertical_layout);
     core->set_history_max(preferences.undo_redo.max_depth);
     core->set_history_never_forgets(preferences.undo_redo.never_forgets);
+    selection_history_manager.set_never_forgets(preferences.undo_redo.never_forgets);
     preferences_apply_appearance(preferences);
 }
 
@@ -1176,22 +1251,10 @@ void ImpBase::add_hamburger_menu()
 void ImpBase::layer_up_down(bool up)
 {
     int wl = canvas->property_work_layer();
-    auto layers = core->get_layer_provider().get_layers();
-    std::vector<int> layer_indexes;
-    layer_indexes.reserve(layers.size());
-    std::transform(layers.begin(), layers.end(), std::back_inserter(layer_indexes),
-                   [](const auto &x) { return x.first; });
-
-    int idx = std::find(layer_indexes.begin(), layer_indexes.end(), wl) - layer_indexes.begin();
-    if (up) {
-        idx++;
-    }
-    else {
-        idx--;
-    }
-    if (idx >= 0 && idx < (int)layers.size()) {
-        canvas->property_work_layer() = layer_indexes.at(idx);
-    }
+    const auto next_layer = core->get_layer_provider().get_adjacent_layer(wl, up ? 1 : -1);
+    if (next_layer == wl)
+        return;
+    canvas->property_work_layer() = next_layer;
 }
 
 void ImpBase::goto_layer(int layer)
@@ -1552,17 +1615,42 @@ void ImpBase::expand_selection_for_property_panel(std::set<SelectableRef> &sel_e
 {
 }
 
+class HistoryItemSelection : public HistoryManager::HistoryItem {
+public:
+    HistoryItemSelection(const std::set<SelectableRef> &sel) : HistoryItem(""), selection(sel)
+    {
+    }
+
+    std::set<SelectableRef> selection;
+};
+
+void ImpBase::selection_push(HistoryManager &mgr, const std::set<SelectableRef> &selection)
+{
+    mgr.push(std::make_unique<HistoryItemSelection>(selection));
+}
+
 void ImpBase::handle_selection_changed(void)
 {
     // std::cout << "Selection changed\n";
     // std::cout << "---" << std::endl;
+    auto selection = canvas->get_selection();
+    if (!selection_loading) {
+        bool push_selection = true;
+        auto &mgr = get_selection_history_manager();
+        if (mgr.has_current()) {
+            auto &it = dynamic_cast<const HistoryItemSelection &>(mgr.get_current());
+            if (it.selection == selection)
+                push_selection = false;
+        }
+        if (push_selection)
+            selection_push(mgr, selection);
+    }
     if (!core->tool_is_active()) {
         clear_highlights();
         update_highlights();
         update_property_panels();
     }
     if (sockets_connected) {
-        auto selection = canvas->get_selection();
         if (selection != last_canvas_selection) {
             handle_selection_cross_probe();
         }
@@ -1570,6 +1658,35 @@ void ImpBase::handle_selection_changed(void)
     }
 }
 
+HistoryManager &ImpBase::get_selection_history_manager()
+{
+    return selection_history_manager;
+}
+
+void ImpBase::selection_load(const HistoryManager::HistoryItem &it)
+{
+    selection_loading = true;
+    auto &its = dynamic_cast<const HistoryItemSelection &>(it);
+    canvas->set_selection(its.selection, true);
+    selection_loading = false;
+}
+
+void ImpBase::selection_undo()
+{
+    auto &mgr = get_selection_history_manager();
+    if (!mgr.can_undo())
+        return;
+    selection_load(mgr.undo());
+}
+
+void ImpBase::selection_redo()
+{
+    auto &mgr = get_selection_history_manager();
+    if (!mgr.can_redo())
+        return;
+    selection_load(mgr.redo());
+}
+
 void ImpBase::update_property_panels()
 {
     auto sel = canvas->get_selection();
@@ -1580,11 +1697,8 @@ void ImpBase::update_property_panels()
         case ObjectType::POLYGON_VERTEX: {
             sel_extra.emplace(it.uuid, ObjectType::POLYGON);
             auto poly = core->get_polygon(it.uuid);
-            if (poly->usage && poly->usage->get_type() == PolygonUsage::Type::PLANE) {
-                sel_extra.emplace(poly->usage->get_uuid(), ObjectType::PLANE);
-            }
-            if (poly->usage && poly->usage->get_type() == PolygonUsage::Type::KEEPOUT) {
-                sel_extra.emplace(poly->usage->get_uuid(), ObjectType::KEEPOUT);
+            if (poly->usage) {
+                sel_extra.emplace(poly->usage->get_uuid(), poly->usage->get_type());
             }
         } break;
         default:;
@@ -1627,8 +1741,9 @@ bool ImpBase::handle_broadcast(const json &j)
 {
     const auto op = j.at("op").get<std::string>();
     guint32 timestamp = j.value("time", 0);
+    std::string token = j.value("token", "");
     if (op == "present") {
-        main_window->present(timestamp);
+        activate_window(main_window, timestamp, token);
         return true;
     }
     else if (op == "save") {
@@ -1729,6 +1844,11 @@ ActionToolID ImpBase::get_doubleclick_action(ObjectType type, const UUID &uu)
     }
 }
 
+LayerProvider &ImpBase::get_layer_provider() const
+{
+    return core->get_layer_provider();
+}
+
 std::map<ObjectType, ImpBase::SelectionFilterInfo> ImpBase::get_selection_filter_info() const
 {
     std::map<ObjectType, ImpBase::SelectionFilterInfo> r;
