@@ -71,6 +71,7 @@ public:
     {
         return false;
     };
+    LayerProvider &get_layer_provider() const;
 
 protected:
     MainWindow *main_window;
@@ -165,6 +166,7 @@ protected:
     void goto_layer(int layer);
 
     Gtk::Button *create_action_button(ActionToolID action);
+    void attach_action_button(Gtk::Button &button, ActionToolID action);
 
     void set_action_sensitive(ActionID, bool v);
     bool get_action_sensitive(ActionID) const;
@@ -267,6 +269,11 @@ protected:
     bool temp_mode = false;
     std::string suggested_filename;
 
+    void selection_load(const HistoryManager::HistoryItem &it);
+    bool selection_loading = false;
+
+    static void selection_push(HistoryManager &mgr, const std::set<SelectableRef> &selection);
+
 private:
     void fix_cursor_pos();
     Glib::RefPtr<Gio::FileMonitor> preferences_monitor;
@@ -359,6 +366,12 @@ private:
     Gtk::Button *undo_button = nullptr;
     Gtk::Button *redo_button = nullptr;
 
+    void selection_undo();
+    void selection_redo();
+
+    HistoryManager selection_history_manager;
+    virtual HistoryManager &get_selection_history_manager();
+
     unsigned int saved_version = 0;
 
     class MSDTuningWindow *msd_tuning_window = nullptr;
