@@ -190,6 +190,11 @@ void ImpBase::update_action_sensitivity()
     set_action_sensitive(ActionID::SAVE, !read_only && core->get_needs_save());
     set_action_sensitive(ActionID::UNDO, core->can_undo());
     set_action_sensitive(ActionID::REDO, core->can_redo());
+    {
+        auto &mgr = get_selection_history_manager();
+        set_action_sensitive(ActionID::UNDO_SELECTION, mgr.can_undo());
+        set_action_sensitive(ActionID::REDO_SELECTION, mgr.can_redo());
+    }
     auto sel = canvas->get_selection();
     set_action_sensitive(ActionID::COPY, sel.size() > 0);
     bool can_select_polygon = std::any_of(sel.begin(), sel.end(), [](const auto &x) {
@@ -211,13 +216,18 @@ Gtk::Button *ImpBase::create_action_button(ActionToolID action)
 {
     auto &catitem = action_catalog.at(action);
     auto button = Gtk::manage(new Gtk::Button(catitem.name));
-    button->signal_clicked().connect([this, action] { trigger_action(action); });
+    attach_action_button(*button, action);
+    return button;
+}
+
+void ImpBase::attach_action_button(Gtk::Button &button, ActionToolID action)
+{
+    button.signal_clicked().connect([this, action] { trigger_action(action); });
     if (action.is_action()) {
         signal_action_sensitive().connect(
-                [this, button, action] { button->set_sensitive(get_action_sensitive(action.action)); });
-        button->set_sensitive(get_action_sensitive(action.action));
+                [this, &button, action] { button.set_sensitive(get_action_sensitive(action.action)); });
+        button.set_sensitive(get_action_sensitive(action.action));
     }
-    return button;
 }
 
 bool ImpBase::trigger_action(ActionToolID action, ActionSource source)
