@@ -25,6 +25,7 @@
 #include "parts_window.hpp"
 #include "actions.hpp"
 #include "in_tool_action.hpp"
+#include "util/gtk_util.hpp"
 
 namespace horizon {
 ImpBoard::ImpBoard(const CoreBoard::Filenames &filenames, const PoolParams &pool_params)
@@ -77,6 +78,12 @@ void ImpBoard::update_highlights()
                     canvas->set_flags(ref, TriangleInfo::FLAG_HIGHLIGHT, 0);
                 }
             }
+            for (const auto &it_plane : core_board.get_board()->planes) {
+                if (it_plane.second.net.uuid == it.uuid) {
+                    ObjectRef ref(ObjectType::PLANE, it_plane.first);
+                    canvas->set_flags(ref, TriangleInfo::FLAG_HIGHLIGHT, 0);
+                }
+            }
             for (const auto &it_via : core_board.get_board()->vias) {
                 if (it_via.second.junction->net.uuid == it.uuid) {
                     ObjectRef ref(ObjectType::VIA, it_via.first);
@@ -143,6 +150,7 @@ bool ImpBoard::handle_broadcast(const json &j)
     if (!ImpBase::handle_broadcast(j)) {
         const auto op = j.at("op").get<std::string>();
         guint32 timestamp = j.value("time", 0);
+        std::string token = j.value("token", "");
         if (op == "highlight" && cross_probing_enabled && !core->tool_is_active()) {
             highlights.clear();
             const json &o = j["objects"];
@@ -166,7 +174,7 @@ bool ImpBoard::handle_broadcast(const json &j)
             update_highlights();
         }
         else if (op == "place") {
-            main_window->present(timestamp);
+            activate_window(main_window, timestamp, token);
             if (force_end_tool()) {
                 std::set<SelectableRef> components;
                 const json &o = j["components"];
@@ -181,7 +189,7 @@ bool ImpBoard::handle_broadcast(const json &j)
             }
         }
         else if (op == "reload-netlist") {
-            main_window->present(timestamp);
+            activate_window(main_window, timestamp, token);
             if (force_end_tool())
                 trigger_action(ActionID::RELOAD_NETLIST);
         }
@@ -291,7 +299,7 @@ void ImpBoard::update_action_sensitivity()
         set_action_sensitive(ActionID::OPEN_DATASHEET, sensitive);
     }
 
-    bool can_select_more = std::any_of(sel.begin(), sel.end(), [](const auto &x) {
+    const bool can_select_more = std::any_of(sel.begin(), sel.end(), [](const auto &x) {
         switch (x.type) {
         case ObjectType::TRACK:
         case ObjectType::JUNCTION:
@@ -303,8 +311,27 @@ void ImpBoard::update_action_sensitivity()
         }
     });
 
-    set_action_sensitive(ActionID::HIGHLIGHT_NET, can_select_more);
-    set_action_sensitive(ActionID::HIGHLIGHT_NET_CLASS, can_select_more);
+    const bool has_plane = std::any_of(sel.begin(), sel.end(), [this](const auto &x) {
+        switch (x.type) {
+        case ObjectType::POLYGON:
+        case ObjectType::POLYGON_ARC_CENTER:
+        case ObjectType::POLYGON_VERTEX:
+        case ObjectType::POLYGON_EDGE: {
+            if (!core_board.get_board()->polygons.count(x.uuid))
+                return false;
+            const auto &poly = *core_board.get_polygon(x.uuid);
+            if (auto plane = dynamic_cast<const Plane *>(poly.usage.ptr))
+                return true;
+        } break;
+
+        default:
+            return false;
+        }
+        return false;
+    });
+
+    set_action_sensitive(ActionID::HIGHLIGHT_NET, can_select_more || has_plane);
+    set_action_sensitive(ActionID::HIGHLIGHT_NET_CLASS, can_select_more || has_plane);
     set_action_sensitive(ActionID::SELECT_MORE, can_select_more);
     set_action_sensitive(ActionID::SELECT_MORE_NO_VIA, can_select_more);
     set_action_sensitive(ActionID::FILTER_AIRWIRES, can_select_more || n_pkgs);
@@ -946,6 +973,14 @@ UUID ImpBoard::net_from_selectable(const SelectableRef &sr)
             return ju.net->uuid;
         }
     } break;
+    case ObjectType::POLYGON_ARC_CENTER:
+    case ObjectType::POLYGON_EDGE:
+    case ObjectType::POLYGON_VERTEX: {
+        auto &poly = board.polygons.at(sr.uuid);
+        if (auto plane = dynamic_cast<const Plane *>(poly.usage.ptr)) {
+            return plane->net->uuid;
+        }
+    } break;
     default:;
     }
     return UUID();
@@ -1272,60 +1307,70 @@ ActionToolID ImpBoard::get_doubleclick_action(ObjectType type, const UUID &uu)
     case ObjectType::POLYGON_EDGE:
     case ObjectType::POLYGON_VERTEX: {
         auto poly = core_board.get_polygon(uu);
-        if (poly->usage) {
-            switch (poly->usage->get_type()) {
-            case PolygonUsage::Type::PLANE:
-                return ToolID::EDIT_PLANE;
-
-            case PolygonUsage::Type::KEEPOUT:
-                return ToolID::EDIT_KEEPOUT;
-
-            default:
-                return {ActionID::NONE, ToolID::NONE};
-            }
-        }
-        else {
+        if (poly->usage->is_type<Plane>())
+            return ToolID::EDIT_PLANE;
+        else if (poly->usage->is_type<Keepout>())
+            return ToolID::EDIT_KEEPOUT;
+        else
             return {ActionID::NONE, ToolID::NONE};
-        }
     } break;
     default:
         return {ActionID::NONE, ToolID::NONE};
     }
 }
 
-
-static void append_bottom_layers(std::vector<int> &layers)
-{
-    std::vector<int> bottoms;
-    bottoms.reserve(layers.size());
-    for (auto it = layers.rbegin(); it != layers.rend(); it++) {
-        if (*it >= 0 && *it != BoardLayers::L_OUTLINE && *it != BoardLayers::OUTLINE_NOTES)
-            bottoms.push_back(-100 - *it);
-    }
-    layers.insert(layers.end(), bottoms.begin(), bottoms.end());
-}
-
 std::map<ObjectType, ImpBase::SelectionFilterInfo> ImpBoard::get_selection_filter_info() const
 {
-    std::vector<int> inner_layers;
-    for (unsigned i = 0; i < core_board.get_board()->get_n_inner_layers(); i++) {
-        inner_layers.push_back(-i - 1);
-    }
-    std::vector<int> layers_line = {BoardLayers::OUTLINE_NOTES, BoardLayers::TOP_ASSEMBLY, BoardLayers::TOP_SILKSCREEN,
-                                    BoardLayers::TOP_MASK, BoardLayers::TOP_COPPER};
-    append_bottom_layers(layers_line);
+    const auto layers_sorted = core_board.get_board()->get_layers_sorted(LayerProvider::LayerSortOrder::TOP_TO_BOTTOM);
 
-    std::vector<int> layers_polygon = {BoardLayers::L_OUTLINE, BoardLayers::TOP_SILKSCREEN, BoardLayers::TOP_MASK,
-                                       BoardLayers::TOP_COPPER};
-    layers_polygon.insert(layers_polygon.end(), inner_layers.begin(), inner_layers.end());
-    append_bottom_layers(layers_polygon);
+    std::vector<int> layers_track;
+    std::vector<int> layers_line;
+    std::vector<int> layers_polygon;
+
+    for (const auto &layer : layers_sorted) {
+        if (layer.copper) {
+            layers_track.push_back(layer.index);
+            layers_polygon.push_back(layer.index);
+        }
+        if (BoardLayers::is_user(layer.index)) {
+            layers_line.push_back(layer.index);
+            layers_polygon.push_back(layer.index);
+        }
+        switch (layer.index) {
+        case BoardLayers::OUTLINE_NOTES:
+            layers_line.push_back(layer.index);
+            break;
+
+        case BoardLayers::L_OUTLINE:
+            layers_line.push_back(layer.index);
+            break;
+
+        case BoardLayers::TOP_ASSEMBLY:
+        case BoardLayers::BOTTOM_ASSEMBLY:
+            layers_line.push_back(layer.index);
+            break;
+
+        case BoardLayers::TOP_SILKSCREEN:
+        case BoardLayers::BOTTOM_SILKSCREEN:
+            layers_line.push_back(layer.index);
+            layers_polygon.push_back(layer.index);
+            break;
+
+        case BoardLayers::TOP_MASK:
+        case BoardLayers::BOTTOM_MASK:
+            layers_line.push_back(layer.index);
+            layers_polygon.push_back(layer.index);
+            break;
+
+        case BoardLayers::TOP_COPPER:
+        case BoardLayers::BOTTOM_COPPER:
+            layers_line.push_back(layer.index);
+            break;
+        }
+    }
 
     std::vector<int> layers_package = {BoardLayers::TOP_COPPER, BoardLayers::BOTTOM_COPPER};
 
-    std::vector<int> layers_track = {BoardLayers::TOP_COPPER};
-    layers_track.insert(layers_track.end(), inner_layers.begin(), inner_layers.end());
-    append_bottom_layers(layers_track);
-
     using Flag = ImpBase::SelectionFilterInfo::Flag;
     std::map<ObjectType, ImpBase::SelectionFilterInfo> r = {
             {ObjectType::BOARD_PACKAGE, {layers_package, Flag::DEFAULT}},
