@@ -16,6 +16,7 @@ public:
     void tool_bar_set_tip(const std::string &s);
     void tool_bar_set_tool_name(const std::string &s);
     void tool_bar_flash(const std::string &s);
+    void tool_bar_flash_replace(const std::string &s);
     void tool_bar_set_actions(const std::vector<ActionLabelInfo> &labels);
 
     void part_placed(const UUID &uu);
@@ -43,6 +44,8 @@ public:
         return s_signal_request_length_tuning_ref;
     }
 
+    void pool_update(const std::vector<std::string> &filenames);
+
 private:
     class ImpBase *imp;
     type_signal_request_length_tuning_ref s_signal_request_length_tuning_ref;
