@@ -11,13 +11,19 @@
 #include "help_texts.hpp"
 #include "actions.hpp"
 #include "rules/rules_window.hpp"
+#include "util/util.hpp"
+#include "util/gtk_util.hpp"
 
 namespace horizon {
-ImpSymbol::ImpSymbol(const std::string &symbol_filename, const std::string &pool_path)
+ImpSymbol::ImpSymbol(const std::string &symbol_filename, const std::string &pool_path, TempMode tmp_mode)
     : ImpBase(pool_path), core_symbol(symbol_filename, *pool), symbol(core_symbol.get_symbol()), searcher(core_symbol)
 {
     core = &core_symbol;
     core_symbol.signal_tool_changed().connect(sigc::mem_fun(*this, &ImpBase::handle_tool_change));
+    if (tmp_mode == TempMode::YES) {
+        core_symbol.set_temp_mode();
+        temp_mode = true;
+    }
 }
 
 void ImpSymbol::canvas_update()
@@ -68,11 +74,13 @@ void ImpSymbol::construct()
     symbol_preview_expand_window = new SymbolPreviewExpandWindow(main_window, core_symbol.get_symbol());
     core->signal_rebuilt().connect([this] { symbol_preview_expand_window->update(); });
 
+
+    connect_action(ActionID::SYMBOL_TEXT_PLACEMENT, [this](const auto &conn) { symbol_preview_window->present(); });
     {
-        auto button = Gtk::manage(new Gtk::Button("Preview…"));
+        auto button = Gtk::manage(new Gtk::Button("Text placement…"));
         main_window->header->pack_start(*button);
         button->show();
-        button->signal_clicked().connect([this] { symbol_preview_window->present(); });
+        button->signal_clicked().connect([this] { trigger_action(ActionID::SYMBOL_TEXT_PLACEMENT); });
     }
 
     unplaced_box = Gtk::manage(new UnplacedBox("Pin"));
@@ -281,10 +289,10 @@ void ImpSymbol::update_bbox_annotation()
     }
     Coordi b = a * -1;
     bbox_annotation->clear();
-    bbox_annotation->draw_line(a, Coordf(b.x, a.y), ColorP::PIN_HIDDEN, 0);
-    bbox_annotation->draw_line(Coordf(b.x, a.y), b, ColorP::PIN_HIDDEN, 0);
-    bbox_annotation->draw_line(b, Coordf(a.x, b.y), ColorP::PIN_HIDDEN, 0);
-    bbox_annotation->draw_line(Coordf(a.x, b.y), a, ColorP::PIN_HIDDEN, 0);
+    bbox_annotation->draw_line(a, Coordf(b.x, a.y), ColorP::SYMBOL_BOUNDING_BOX, 0);
+    bbox_annotation->draw_line(Coordf(b.x, a.y), b, ColorP::SYMBOL_BOUNDING_BOX, 0);
+    bbox_annotation->draw_line(b, Coordf(a.x, b.y), ColorP::SYMBOL_BOUNDING_BOX, 0);
+    bbox_annotation->draw_line(Coordf(a.x, b.y), a, ColorP::SYMBOL_BOUNDING_BOX, 0);
 }
 
 
@@ -311,4 +319,23 @@ unsigned int ImpSymbol::get_required_version() const
         return 0;
 }
 
+bool ImpSymbol::set_filename()
+{
+    GtkFileChooserNative *native = gtk_file_chooser_native_new("Save Symbol", GTK_WINDOW(main_window->gobj()),
+                                                               GTK_FILE_CHOOSER_ACTION_SAVE, "_Save", "_Cancel");
+    auto chooser = Glib::wrap(GTK_FILE_CHOOSER(native));
+    chooser->set_do_overwrite_confirmation(true);
+
+    chooser->set_current_folder(get_existing_path(Glib::path_get_dirname(suggested_filename)));
+    chooser->set_current_name(Glib::path_get_basename(suggested_filename));
+
+    std::string filename;
+    auto success = run_native_filechooser_with_retry(chooser, "Error saving symbol", [this, chooser, &filename] {
+        filename = append_dot_json(chooser->get_filename());
+        pool->check_filename_throw(ObjectType::SYMBOL, filename);
+        core_symbol.set_filename(filename);
+    });
+    return success;
+}
+
 } // namespace horizon
