@@ -24,6 +24,9 @@ const std::map<InToolActionID, InToolActionCatalogItem> in_tool_action_catalog =
          {"decrease net label size", ToolID::NONE, InToolActionCatalogItem::FLAGS_DEFAULT}},
         {InToolActionID::FLIP_ARC, {"flip arc", ToolID::NONE, InToolActionCatalogItem::FLAGS_DEFAULT}},
 
+        {InToolActionID::SELECT_VIA_DEFINITION,
+         {"select via definition", ToolID::NONE, InToolActionCatalogItem::FLAGS_DEFAULT}},
+
         {InToolActionID::TOGGLE_ARC, {"toggle arc", ToolID::DRAW_POLYGON, InToolActionCatalogItem::FLAGS_DEFAULT}},
 
         {InToolActionID::DIMENSION_MODE,
@@ -48,6 +51,8 @@ const std::map<InToolActionID, InToolActionCatalogItem> in_tool_action_catalog =
          {"autoplace next", ToolID::MAP_PIN, InToolActionCatalogItem::FLAGS_DEFAULT}},
         {InToolActionID::AUTOPLACE_ALL_PINS,
          {"autoplace all", ToolID::MAP_PIN, InToolActionCatalogItem::FLAGS_DEFAULT}},
+        {InToolActionID::TOGGLE_NAME_ORIENTATION,
+         {"name orientation", ToolID::MAP_PIN, InToolActionCatalogItem::FLAGS_DEFAULT}},
 
         {InToolActionID::TOGGLE_ANGLE_SNAP,
          {"toggle angle snap", ToolID::ROTATE_ARBITRARY, InToolActionCatalogItem::FLAGS_DEFAULT}},
@@ -127,6 +132,7 @@ const LutEnumStr<InToolActionID> in_tool_action_lut = {
         LUT_ITEM(TOGGLE_ARC),
         LUT_ITEM(DIMENSION_MODE),
         LUT_ITEM(PLACE_JUNCTION),
+        LUT_ITEM(SELECT_VIA_DEFINITION),
         LUT_ITEM(ARBITRARY_ANGLE_MODE),
         LUT_ITEM(TOGGLE_NET_LABEL),
         LUT_ITEM(POLYGON_DECORATION_POSITION),
@@ -135,6 +141,7 @@ const LutEnumStr<InToolActionID> in_tool_action_lut = {
         LUT_ITEM(POLYGON_CORNER_RADIUS),
         LUT_ITEM(AUTOPLACE_NEXT_PIN),
         LUT_ITEM(AUTOPLACE_ALL_PINS),
+        LUT_ITEM(TOGGLE_NAME_ORIENTATION),
         LUT_ITEM(TOGGLE_ANGLE_SNAP),
         LUT_ITEM(LENGTH_TUNING_LENGTH),
         LUT_ITEM(LENGTH_TUNING_AMPLITUDE_INC),
