@@ -30,6 +30,15 @@ static const char *text_sym =
         "• No overlapping pins\n"
         "• Pin placement\n";
 
+static const char *text_net_ties =
+        "This rule checks if all net ties are correctly represented on the board:\n"
+        "• No missing net ties\n"
+        "• Net tie connects to its designated nets\n";
+
+static const char *text_board_connectivity =
+        "This rule checks if all copper features of each net are connected to one another:\n"
+        "• Connected by PTH holes such as vias or through-hole pins\n"
+        "• Connected by shorted pads as specfied in the the shorted pads rule\n";
 
 void RuleEditorPackageChecks::populate()
 {
@@ -47,6 +56,14 @@ void RuleEditorPackageChecks::populate()
         editor->set_text(text_sym);
         break;
 
+    case RuleID::NET_TIES:
+        editor->set_text(text_net_ties);
+        break;
+
+    case RuleID::BOARD_CONNECTIVITY:
+        editor->set_text(text_board_connectivity);
+        break;
+
     default:
         break;
     }
