@@ -3,15 +3,18 @@
 #include "document/idocument.hpp"
 #include "rules/rule_match.hpp"
 #include "widgets/net_button.hpp"
+#include "widgets/multi_net_button.hpp"
 #include "widgets/net_class_button.hpp"
 
+
 namespace horizon {
 RuleMatchEditor::RuleMatchEditor(RuleMatch &ma, class IDocument &c)
     : Gtk::Box(Gtk::ORIENTATION_VERTICAL, 4), match(ma), core(c)
 {
     combo_mode = Gtk::manage(new Gtk::ComboBoxText());
     combo_mode->append(std::to_string(static_cast<int>(RuleMatch::Mode::ALL)), "All");
-    combo_mode->append(std::to_string(static_cast<int>(RuleMatch::Mode::NET)), "Net");
+    combo_mode->append(std::to_string(static_cast<int>(RuleMatch::Mode::NET)), "Single net");
+    combo_mode->append(std::to_string(static_cast<int>(RuleMatch::Mode::NETS)), "Multiple nets");
     combo_mode->append(std::to_string(static_cast<int>(RuleMatch::Mode::NET_CLASS)), "Net class");
     combo_mode->append(std::to_string(static_cast<int>(RuleMatch::Mode::NET_NAME_REGEX)), "Net name (regex)");
     combo_mode->append(std::to_string(static_cast<int>(RuleMatch::Mode::NET_CLASS_REGEX)), "Net class (regex)");
@@ -22,7 +25,7 @@ RuleMatchEditor::RuleMatchEditor(RuleMatch &ma, class IDocument &c)
         s_signal_updated.emit();
     });
 
-    pack_start(*combo_mode, true, true, 0);
+    pack_start(*combo_mode, false, false, 0);
     combo_mode->show();
 
     sel_stack = Gtk::manage(new Gtk::Stack());
@@ -30,6 +33,7 @@ RuleMatchEditor::RuleMatchEditor(RuleMatch &ma, class IDocument &c)
     Block &block = *core.get_top_block();
 
     net_button = Gtk::manage(new NetButton(block));
+    net_button->set_no_expand(true);
     net_button->set_net(match.net);
     net_button->signal_changed().connect([this](const UUID &uu) {
         match.net = uu;
@@ -37,6 +41,14 @@ RuleMatchEditor::RuleMatchEditor(RuleMatch &ma, class IDocument &c)
     });
     sel_stack->add(*net_button, std::to_string(static_cast<int>(RuleMatch::Mode::NET)));
 
+    multi_net_button = Gtk::manage(new MultiNetButton(block));
+    multi_net_button->set_items(match.nets);
+    multi_net_button->signal_changed().connect([this] {
+        match.nets = multi_net_button->get_items();
+        s_signal_updated.emit();
+    });
+    sel_stack->add(*multi_net_button, std::to_string(static_cast<int>(RuleMatch::Mode::NETS)));
+
     net_class_button = Gtk::manage(new NetClassButton(*core.get_top_block()));
     if (!match.net_class) {
         match.net_class = core.get_top_block()->net_class_default->uuid;
