@@ -4,7 +4,7 @@
 namespace horizon {
 class RuleMatchKeepoutEditor : public Gtk::Box {
 public:
-    RuleMatchKeepoutEditor(class RuleMatchKeepout *ma, class IDocument *c);
+    RuleMatchKeepoutEditor(class RuleMatchKeepout &ma, class IDocument &c);
     typedef sigc::signal<void> type_signal_updated;
     type_signal_updated signal_updated()
     {
@@ -15,8 +15,8 @@ private:
     Gtk::ComboBoxText *combo_mode = nullptr;
     Gtk::Stack *sel_stack = nullptr;
     Gtk::Entry *keepout_class_entry = nullptr;
-    RuleMatchKeepout *match;
-    class IDocument *core;
+    RuleMatchKeepout &match;
+    class IDocument &core;
     type_signal_updated s_signal_updated;
     class ComponentButton *component_button = nullptr;
 };
