@@ -1,10 +1,11 @@
 #pragma once
-#include "util/uuid.hpp"
+#include "util/changeable.hpp"
 
 namespace horizon {
-class DuplicateBase {
+class DuplicateBase : public Changeable {
 public:
     virtual UUID duplicate(std::vector<std::string> *filenames = nullptr) = 0;
+    virtual bool check_valid() = 0;
     virtual ~DuplicateBase()
     {
     }
