@@ -9,6 +9,8 @@
 #include "widgets/help_button.hpp"
 #include "help_texts.hpp"
 #include "widgets/pin_names_editor.hpp"
+#include "nlohmann/json.hpp"
+#include "checks/check_unit.hpp"
 
 namespace horizon {
 
@@ -84,8 +86,12 @@ PinEditor::PinEditor(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder> &
     dir_combo->set_active_id(std::to_string(static_cast<int>(pin->direction)));
     dir_combo->signal_changed().connect([this, propagate] {
         pin->direction = static_cast<Pin::Direction>(std::stoi(dir_combo->get_active_id()));
+        if (parent->propagating)
+            return;
+        parent->propagating = true;
         propagate([this](PinEditor *ed) { ed->dir_combo->set_active_id(dir_combo->get_active_id()); });
         parent->set_needs_save();
+        parent->propagating = false;
     });
 }
 
@@ -125,15 +131,19 @@ void UnitEditor::sort()
     pins_listbox->unset_sort_func();
 }
 
-UnitEditor::UnitEditor(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder> &x, Unit &u, class IPool &p)
-    : Gtk::Box(cobject), unit(u), pool(p)
+UnitEditor::UnitEditor(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder> &x, const std::string &fn,
+                       class IPool &p)
+    : Gtk::Box(cobject), PoolEditorBase(fn, p),
+      unit(filename.size() ? Unit::new_from_file(filename) : Unit(UUID::random()))
 {
+    history_append("init");
     x->get_widget("unit_name", name_entry);
     x->get_widget("unit_manufacturer", manufacturer_entry);
     x->get_widget("unit_pins", pins_listbox);
     x->get_widget("pin_add", add_button);
     x->get_widget("pin_delete", delete_button);
     x->get_widget("cross_probing", cross_probing_cb);
+    x->get_widget("pin_count", pin_count_label);
     entry_add_sanitizer(name_entry);
     entry_add_sanitizer(manufacturer_entry);
 
@@ -143,25 +153,20 @@ UnitEditor::UnitEditor(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder>
 
     HelpButton::pack_into(x, "box_names", HelpTexts::UNIT_PIN_ALT_NAMES);
 
-    name_entry->set_text(unit.name);
     name_entry->signal_changed().connect([this] {
+        if (is_loading())
+            return;
         unit.name = name_entry->get_text();
         set_needs_save();
     });
-    manufacturer_entry->set_text(unit.manufacturer);
     manufacturer_entry->set_completion(create_pool_manufacturer_completion(pool));
     manufacturer_entry->signal_changed().connect([this] {
+        if (is_loading())
+            return;
         unit.manufacturer = manufacturer_entry->get_text();
         set_needs_save();
     });
 
-    for (auto &it : unit.pins) {
-        auto ed = PinEditor::create(&it.second, this);
-        ed->show_all();
-        pins_listbox->append(*ed);
-        ed->unreference();
-    }
-
     delete_button->signal_clicked().connect(sigc::mem_fun(*this, &UnitEditor::handle_delete));
     add_button->signal_clicked().connect(sigc::mem_fun(*this, &UnitEditor::handle_add));
 
@@ -176,12 +181,36 @@ UnitEditor::UnitEditor(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder>
     sort_helper.attach("pin", x);
     sort_helper.attach("direction", x);
     sort_helper.signal_changed().connect(sigc::mem_fun(*this, &UnitEditor::sort));
+
+    label_set_tnum(pin_count_label);
+
+    load();
+}
+
+void UnitEditor::load()
+{
+    auto loading_setter = set_loading();
+
+    name_entry->set_text(unit.name);
+    manufacturer_entry->set_text(unit.manufacturer);
+    for (auto ch : pins_listbox->get_children()) {
+        delete ch;
+    }
+    for (auto &it : unit.pins) {
+        auto ed = PinEditor::create(&it.second, this);
+        ed->show_all();
+        pins_listbox->append(*ed);
+        ed->unreference();
+    }
     sort_helper.set_sort("pin", Gtk::SORT_ASCENDING);
+    update_pin_count();
 }
 
 void UnitEditor::handle_delete()
 {
     auto rows = pins_listbox->get_selected_rows();
+    if (rows.size() == 0)
+        return;
     std::set<int> indices;
     std::set<UUID> uuids;
     for (auto &row : rows) {
@@ -205,6 +234,7 @@ void UnitEditor::handle_delete()
             pins_listbox->select_row(*row);
     }
     set_needs_save();
+    update_pin_count();
 }
 
 static std::string inc_pin_name(const std::string &s, int inc = 1)
@@ -278,6 +308,7 @@ void UnitEditor::handle_add()
         }
     }
     set_needs_save();
+    update_pin_count();
 }
 
 void UnitEditor::handle_activate(PinEditor *ed)
@@ -307,6 +338,17 @@ void UnitEditor::handle_activate(PinEditor *ed)
     }
 }
 
+void UnitEditor::update_pin_count()
+{
+    const uint32_t n = unit.pins.size();
+    std::string s = std::to_string(n);
+    if (n == 1)
+        s += " pin";
+    else
+        s += " pins";
+    pin_count_label->set_text(s);
+}
+
 void UnitEditor::select(const ItemSet &items)
 {
     if (!cross_probing_cb->get_active())
@@ -322,13 +364,71 @@ void UnitEditor::select(const ItemSet &items)
     }
 }
 
-UnitEditor *UnitEditor::create(Unit &u, class IPool &p)
+void UnitEditor::save_as(const std::string &fn)
+{
+    unset_needs_save();
+    filename = fn;
+    save_json_to_file(fn, unit.serialize());
+}
+
+std::string UnitEditor::get_name() const
+{
+    return unit.name;
+}
+
+const UUID &UnitEditor::get_uuid() const
+{
+    return unit.uuid;
+}
+
+RulesCheckResult UnitEditor::run_checks() const
+{
+    return check_unit(unit);
+}
+
+const FileVersion &UnitEditor::get_version() const
+{
+    return unit.version;
+}
+
+unsigned int UnitEditor::get_required_version() const
+{
+    return unit.get_required_version();
+}
+
+ObjectType UnitEditor::get_type() const
+{
+    return ObjectType::UNIT;
+}
+
+class HistoryItemUnit : public HistoryManager::HistoryItem {
+public:
+    HistoryItemUnit(const Unit &u, const std::string &cm) : HistoryManager::HistoryItem(cm), unit(u)
+    {
+    }
+    Unit unit;
+};
+
+std::unique_ptr<HistoryManager::HistoryItem> UnitEditor::make_history_item(const std::string &comment)
+{
+    return std::make_unique<HistoryItemUnit>(unit, comment);
+}
+
+void UnitEditor::history_load(const HistoryManager::HistoryItem &it)
+{
+    const auto &x = dynamic_cast<const HistoryItemUnit &>(it);
+    unit = x.unit;
+    load();
+}
+
+UnitEditor *UnitEditor::create(const std::string &fn, class IPool &p)
 {
     UnitEditor *w;
     Glib::RefPtr<Gtk::Builder> x = Gtk::Builder::create();
     x->add_from_resource("/org/horizon-eda/horizon/pool-prj-mgr/pool-mgr/editors/unit_editor.ui");
-    x->get_widget_derived("unit_editor", w, u, p);
+    x->get_widget_derived("unit_editor", w, fn, p);
     w->reference();
     return w;
 }
+
 } // namespace horizon
