@@ -76,11 +76,13 @@ void GateEditorImportWizard::handle_edit_unit()
 {
     std::string filename = parent.pool.get_tmp_filename(ObjectType::UNIT, unit_uu);
     auto proc = parent.appwin.spawn(PoolProjectManagerProcess::Type::UNIT, {filename});
-    parent.processes.emplace(filename, proc);
-    proc->signal_exited().connect([this, filename](int status, bool modified) {
-        parent.processes.erase(filename);
-        parent.update_can_finish();
-    });
+    if (proc.spawned) {
+        parent.processes.emplace(filename, proc.proc);
+        proc.proc->signal_exited().connect([this, filename](int status, bool modified) {
+            parent.processes.erase(filename);
+            parent.update_can_finish();
+        });
+    }
     parent.update_can_finish();
 }
 
@@ -88,11 +90,13 @@ void GateEditorImportWizard::handle_edit_symbol()
 {
     std::string filename = parent.pool.get_tmp_filename(ObjectType::SYMBOL, parent.symbols.at(unit_uu));
     auto proc = parent.appwin.spawn(PoolProjectManagerProcess::Type::IMP_SYMBOL, {filename});
-    parent.processes.emplace(filename, proc);
-    proc->signal_exited().connect([this, filename](int status, bool modified) {
-        parent.processes.erase(filename);
-        parent.update_can_finish();
-    });
+    if (proc.spawned) {
+        parent.processes.emplace(filename, proc.proc);
+        proc.proc->signal_exited().connect([this, filename](int status, bool modified) {
+            parent.processes.erase(filename);
+            parent.update_can_finish();
+        });
+    }
     parent.update_can_finish();
 }
 
