@@ -98,6 +98,7 @@ PoolSettingsBox::PoolSettingsBox(BaseObjectType *cobject, const Glib::RefPtr<Gtk
 
     update_pools();
     update_actual();
+    PoolManager::get().signal_written().connect(sigc::mem_fun(*this, &PoolSettingsBox::update_pools));
 }
 
 PoolSettingsBox *PoolSettingsBox::create(IPool &p)
@@ -188,6 +189,9 @@ PoolListItem::PoolListItem(const UUID &uu, bool avail)
         if (pool)
             base_path = pool->base_path;
         la->set_xalign(0);
+        la->set_ellipsize(Pango::ELLIPSIZE_START);
+        if (pool)
+            la->set_tooltip_text(pool->base_path);
         pack_start(*la, true, true, 0);
         la->show();
     }
