@@ -46,11 +46,12 @@ public:
     void close_appwindows(std::set<Gtk::Window *> wins);
     Preferences &get_preferences();
 
-    class PoolProjectManagerAppWindow &open_pool_or_project(const std::string &pool_json, guint32 timestamp = 0);
+    class PoolProjectManagerAppWindow &open_pool_or_project(const std::string &pool_json, guint32 timestamp = 0,
+                                                            const std::string &token = "");
 
-    class PreferencesWindow *show_preferences_window(guint32 timestamp = 0);
-    class PoolsWindow *show_pools_window(guint32 timestamp = 0);
-    class LogWindow *show_log_window(guint32 timestamp = 0);
+    class PreferencesWindow *show_preferences_window(guint32 timestamp = 0, const std::string &token = "");
+    class PoolsWindow *show_pools_window(guint32 timestamp = 0, const std::string &token = "");
+    class LogWindow *show_log_window(guint32 timestamp = 0, const std::string &token = "");
 
     typedef sigc::signal<void, std::vector<std::string>> type_signal_pool_items_edited;
     type_signal_pool_items_edited signal_pool_items_edited()
