@@ -19,8 +19,8 @@ PoolIndex::PoolIndex(const UUID &uu, const json &j) : uuid(uu), name(j.at("name"
     if (source != "github") {
         throw std::runtime_error("unsupported source " + source);
     }
-    gh_user = j.at("source").at("user");
-    gh_repo = j.at("source").at("repo");
+    gh_user = j.at("source").at("user").get<std::string>();
+    gh_repo = j.at("source").at("repo").get<std::string>();
     for (const auto &[k, v] : j.at("type_stats").items()) {
         type_stats.emplace(object_type_lut.lookup(k), v.get<unsigned int>());
     }
