@@ -7,12 +7,10 @@ namespace horizon {
 class PreferencesWindow : public Gtk::Window {
 public:
     PreferencesWindow(class Preferences &pr);
-    void open_pool(const std::string &path = "");
     void show_page(const std::string &pg);
 
 private:
     class Preferences &preferences;
-    class PoolPreferencesEditor *pool_prefs_editor = nullptr;
     Gtk::Stack *stack = nullptr;
 };
 } // namespace horizon
