@@ -2,6 +2,7 @@
 #include <gtkmm.h>
 #include <memory>
 #include <zmq.hpp>
+#include <optional>
 
 namespace horizon {
 
@@ -10,7 +11,8 @@ public:
     PoolProjectManagerViewCreateProject(const Glib::RefPtr<Gtk::Builder> &refBuilder,
                                         class PoolProjectManagerAppWindow &w);
     void clear();
-    std::pair<bool, std::string> create();
+    void focus();
+    std::optional<std::string> create();
     typedef sigc::signal<void, bool> type_signal_valid_change;
     type_signal_valid_change signal_valid_change()
     {
@@ -36,12 +38,14 @@ public:
     Gtk::Label *label_project_title = nullptr;
     Gtk::Label *label_project_author = nullptr;
     Gtk::Label *label_project_directory = nullptr;
+    Gtk::Label *label_project_pools = nullptr;
 
     void open_top_schematic();
     void open_board();
     bool update_meta();
     void update_pool_cache_status(const class PoolCacheStatus &status);
     void reset_pool_cache_status();
+    void update_pools_label();
 
 private:
     PoolProjectManagerAppWindow &win;
@@ -51,6 +55,8 @@ private:
     Gtk::Button *button_project_pool = nullptr;
     Gtk::Label *pool_cache_status_label = nullptr;
 
+    class OpeningSpinner *board_spinner = nullptr;
+    class OpeningSpinner *schematic_spinner = nullptr;
 
     void handle_button_part_browser();
     void handle_button_project_pool();
