@@ -9,7 +9,7 @@ namespace horizon {
 class PoolUpdater {
 public:
     PoolUpdater(const std::string &bp, pool_update_cb_t status_cb);
-    void update(const std::vector<std::string> &base_paths);
+    void update();
     void update_some(const std::vector<std::string> &filenames, std::set<UUID> &all_parts_updated);
 
     PoolUpdatePool &get_pool()
@@ -17,9 +17,19 @@ public:
         return *pool;
     }
 
+    bool was_partial_update() const
+    {
+        return is_partial_update;
+    }
+
+    class CompletePoolUpdateRequiredException {
+    public:
+    };
+
 private:
     std::optional<PoolUpdatePool> pool;
     std::optional<SQLite::Query> q_exists;
+    std::optional<SQLite::Query> q_exists_by_filename;
     std::optional<SQLite::Query> q_add_dependency;
     std::optional<SQLite::Query> q_insert_part;
     std::optional<SQLite::Query> q_add_tag;
@@ -46,7 +56,7 @@ private:
     void clear_tags(ObjectType type, const UUID &uu);
     std::optional<std::pair<UUID, UUID>> exists(ObjectType type, const UUID &uu);
     void delete_item(ObjectType type, const UUID &uu);
-    std::optional<UUID> handle_override(ObjectType type, const UUID &u);
+    std::optional<UUID> handle_override(ObjectType type, const UUID &u, const std::string &filename);
 
     void update_frame(const std::string &filename);
     void update_decal(const std::string &filename);
@@ -66,6 +76,8 @@ private:
     void set_pool_info(const std::string &bp);
     std::string get_path_rel(const std::string &filename) const;
 
+    std::vector<std::string> update_included_pools();
+
     static std::filesystem::file_time_type::duration::rep get_mtime(const std::string &filename);
 };
 } // namespace horizon
