@@ -66,7 +66,7 @@ public:
 
     UUID get_uuid() const;
     std::pair<Coordi, Coordi> get_bbox(bool copper_only = false) const;
-    void expand_inner(unsigned int n_inner);
+    void expand_inner(unsigned int n_inner, const class LayerRange &span);
     const std::map<int, Layer> &get_layers() const override;
 
 private:
