@@ -184,6 +184,7 @@ const std::string &Part::get_attribute(Attribute a) const
         }
     }
     else {
+        static const std::string empty;
         return empty;
     }
 }
@@ -270,6 +271,16 @@ const std::string &Part::get_prefix() const
     }
 }
 
+Part::OverridePrefix Part::get_override_prefix() const
+{
+    if (base && override_prefix == OverridePrefix::INHERIT)
+        return base->get_override_prefix();
+    else if (override_prefix == OverridePrefix::INHERIT)
+        return OverridePrefix::NO;
+    else
+        return override_prefix;
+}
+
 Part::Part(const UUID &uu) : uuid(uu), version(app_version)
 {
     attributes[Attribute::MPN] = {false, ""};
@@ -366,10 +377,10 @@ UUID Part::get_uuid() const
 
 void Part::update_refs(IPool &pool)
 {
-    entity = pool.get_entity(entity.uuid);
-    package = pool.get_package(package.uuid);
-    if (base.ptr)
-        base = pool.get_part(base.uuid);
+    entity = pool.get_entity(entity->uuid);
+    package = pool.get_package(package->uuid);
+    if (base)
+        base = pool.get_part(base->uuid);
     for (auto &it : pad_map) {
         it.second.gate = &entity->gates.at(it.second.gate.uuid);
         it.second.pin = &it.second.gate->unit->pins.at(it.second.pin.uuid);
@@ -382,11 +393,11 @@ ItemSet Part::get_pool_items_used() const
     auto part = this;
     while (part) {
         items_needed.emplace(ObjectType::PART, part->uuid);
-        items_needed.emplace(ObjectType::PACKAGE, part->package.uuid);
+        items_needed.emplace(ObjectType::PACKAGE, part->package->uuid);
         for (const auto &it_pad : part->package->pads) {
             items_needed.emplace(ObjectType::PADSTACK, it_pad.second.pool_padstack->uuid);
         }
-        part = part->base;
+        part = part->base.get();
     }
     return items_needed;
 }
