@@ -15,7 +15,6 @@ using json = nlohmann::json;
 class Part {
 private:
     Part(const UUID &uu, const json &j, class IPool &pool);
-    const std::string empty;
 
 public:
     class PadMapItem {
@@ -49,11 +48,11 @@ public:
 
     std::set<std::string> tags;
     bool inherit_tags = false;
-    uuid_ptr<const class Entity> entity;
-    uuid_ptr<const class Package> package;
+    std::shared_ptr<const class Entity> entity;
+    std::shared_ptr<const class Package> package;
     UUID model;
     bool inherit_model = true;
-    uuid_ptr<const class Part> base;
+    std::shared_ptr<const class Part> base;
 
     void update_refs(IPool &pool);
     UUID get_uuid() const;
@@ -64,8 +63,8 @@ public:
         Column(const std::string &d, const std::string &v) : display_name(d), value(v)
         {
         }
-        const std::string display_name;
-        const std::string value;
+        std::string display_name;
+        std::string value;
     };
     std::map<std::string, Column> parametric_formatted;
 
@@ -80,6 +79,7 @@ public:
     OverridePrefix override_prefix = OverridePrefix::NO;
     std::string prefix;
     const std::string &get_prefix() const;
+    OverridePrefix get_override_prefix() const;
 
     ItemSet get_pool_items_used() const;
 
