@@ -27,10 +27,19 @@ public:
     const std::map<std::string, PoolManagerPool> &get_pools() const;
     const PoolManagerPool *get_by_uuid(const UUID &uu) const;
     const PoolManagerPool *get_for_file(const std::string &filename) const;
+    bool reload();
+
+    typedef sigc::signal<void> type_signal_written;
+    type_signal_written signal_written()
+    {
+        return s_signal_written;
+    }
 
 private:
     std::map<std::string, PoolManagerPool> pools;
     void set_pool_enabled_no_write(const std::string &base_path, bool enabled);
     void write();
+
+    type_signal_written s_signal_written;
 };
 } // namespace horizon
