@@ -7,6 +7,7 @@
 #include "nlohmann/json.hpp"
 #include <algorithm>
 #include "util/bbox_accumulator.hpp"
+#include "common/junction_util.hpp"
 
 namespace horizon {
 
@@ -251,12 +252,26 @@ void Symbol::expand(PinDisplayMode mode)
     }
 }
 
+void Symbol::update_junction_connections()
+{
+
+    for (auto &[uu, it] : junctions) {
+        it.clear();
+    }
+
+    JunctionUtil::update(lines);
+    JunctionUtil::update(arcs);
+}
+
 std::pair<Coordi, Coordi> Symbol::get_bbox(bool all) const
 {
     BBoxAccumulator<Coordi::type> acc;
     for (const auto &it : junctions) {
         acc.accumulate(it.second.position);
     }
+    for (const auto &it : arcs) {
+        acc.accumulate(it.second.get_bbox());
+    }
     for (const auto &it : pins) {
         acc.accumulate(it.second.position);
     }
