@@ -3,7 +3,8 @@
 #include "project/project.hpp"
 extern PyTypeObject BoardType;
 
-class BoardWrapper *create_board_wrapper(const horizon::Project &prj);
+enum class PlaneMode { LOAD_FROM_FILE, UPDATE };
+class BoardWrapper *create_board_wrapper(const horizon::Project &prj, PlaneMode plane_mode);
 
 typedef struct {
     PyObject_HEAD
