@@ -32,6 +32,14 @@ int PNS_HORIZON_IFACE::layer_to_router(int l)
         return In3_Cu;
     case horizon::BoardLayers::IN4_COPPER:
         return In4_Cu;
+    case horizon::BoardLayers::IN5_COPPER:
+        return In5_Cu;
+    case horizon::BoardLayers::IN6_COPPER:
+        return In6_Cu;
+    case horizon::BoardLayers::IN7_COPPER:
+        return In7_Cu;
+    case horizon::BoardLayers::IN8_COPPER:
+        return In8_Cu;
     default:
         return UNDEFINED_LAYER;
     }
@@ -61,6 +69,18 @@ int PNS_HORIZON_IFACE::layer_from_router(int l)
     case In4_Cu:
         lo = horizon::BoardLayers::IN4_COPPER;
         break;
+    case In5_Cu:
+        lo = horizon::BoardLayers::IN5_COPPER;
+        break;
+    case In6_Cu:
+        lo = horizon::BoardLayers::IN6_COPPER;
+        break;
+    case In7_Cu:
+        lo = horizon::BoardLayers::IN7_COPPER;
+        break;
+    case In8_Cu:
+        lo = horizon::BoardLayers::IN8_COPPER;
+        break;
     case UNDEFINED_LAYER:
         lo = 10000;
         break;
@@ -174,11 +194,11 @@ int PNS_HORIZON_RULE_RESOLVER::Clearance(const PNS::ITEM *aA, const PNS::ITEM *a
         // fixme: handle multiple layers for non-edge thing
         auto layer = layers.Start();
 
-        auto clearance = m_rules->get_clearance_copper_other(net, PNS_HORIZON_IFACE::layer_from_router(layer));
-        int64_t routing_offset = clearance->routing_offset;
+        const auto &clearance = m_rules->get_clearance_copper_other(net, PNS_HORIZON_IFACE::layer_from_router(layer));
+        int64_t routing_offset = clearance.routing_offset;
         if (m_iface->get_override_routing_offset() >= 0)
             routing_offset = m_iface->get_override_routing_offset();
-        return clearance->get_clearance(pt, horizon::PatchType::BOARD_EDGE) + routing_offset;
+        return clearance.get_clearance(pt, horizon::PatchType::BOARD_EDGE) + routing_offset;
     }
 
     if ((parent_a && parent_a->pad && parent_a->pad->padstack.type == horizon::Padstack::Type::MECHANICAL)
@@ -199,11 +219,11 @@ int PNS_HORIZON_RULE_RESOLVER::Clearance(const PNS::ITEM *aA, const PNS::ITEM *a
         // fixme: handle multiple layers for non-npth thing
         auto layer = layers.Start();
 
-        auto clearance = m_rules->get_clearance_copper_other(net, PNS_HORIZON_IFACE::layer_from_router(layer));
-        int64_t routing_offset = clearance->routing_offset;
+        const auto &clearance = m_rules->get_clearance_copper_other(net, PNS_HORIZON_IFACE::layer_from_router(layer));
+        int64_t routing_offset = clearance.routing_offset;
         if (m_iface->get_override_routing_offset() >= 0)
             routing_offset = m_iface->get_override_routing_offset();
-        return clearance->get_clearance(pt, horizon::PatchType::HOLE_NPTH) + routing_offset;
+        return clearance.get_clearance(pt, horizon::PatchType::HOLE_NPTH) + routing_offset;
     }
 
     if ((parent_a && parent_a->keepout) || (parent_b && parent_b->keepout)) { // one is keepout
@@ -240,13 +260,13 @@ int PNS_HORIZON_RULE_RESOLVER::Clearance(const PNS::ITEM *aA, const PNS::ITEM *a
 
     assert(layer != UNDEFINED_LAYER);
 
-    auto clearance = m_rules->get_clearance_copper(net_a, net_b, PNS_HORIZON_IFACE::layer_from_router(layer));
+    const auto &clearance = m_rules->get_clearance_copper(net_a, net_b, PNS_HORIZON_IFACE::layer_from_router(layer));
 
-    int64_t routing_offset = clearance->routing_offset;
+    int64_t routing_offset = clearance.routing_offset;
     if (m_iface->get_override_routing_offset() >= 0)
         routing_offset = m_iface->get_override_routing_offset();
 
-    return clearance->get_clearance(pt_a, pt_b) + routing_offset;
+    return clearance.get_clearance(pt_a, pt_b) + routing_offset;
 }
 
 int PNS_HORIZON_RULE_RESOLVER::HoleClearance(const PNS::ITEM *aA, const PNS::ITEM *aB)
@@ -378,6 +398,28 @@ horizon::Net *PNS_HORIZON_IFACE::get_net_for_code(int code)
     return net_code_map_r.at(code);
 }
 
+horizon::UUID PNS_HORIZON_IFACE::get_via_definition_for_code(int code)
+{
+    if (code < 0)
+        return {};
+    if (code >= (int)via_definition_code_map_r.size())
+        return {};
+    return via_definition_code_map_r.at(code);
+}
+
+int PNS_HORIZON_IFACE::get_via_definition_code(const horizon::UUID &uu)
+{
+    if (via_definition_code_map.count(uu)) {
+        return via_definition_code_map.at(uu);
+    }
+    else {
+        via_definition_code_map_r.emplace_back(uu);
+        auto nc = via_definition_code_map_r.size() - 1;
+        via_definition_code_map.emplace(uu, nc);
+        return nc;
+    }
+}
+
 const PNS_HORIZON_PARENT_ITEM *PNS_HORIZON_IFACE::get_parent(const horizon::Track *track)
 {
     return get_or_create_parent(PNS_HORIZON_PARENT_ITEM(track));
@@ -696,14 +738,14 @@ std::unique_ptr<PNS::VIA> PNS_HORIZON_IFACE::syncVia(const horizon::Via *via)
 {
     auto pos = via->junction->position;
     int net = PNS::ITEM::UnusedNet;
+    const auto &span = via->span;
     if (via->junction->net)
         net = get_net_code(via->junction->net->uuid);
-    std::unique_ptr<PNS::VIA> pvia(new PNS::VIA(VECTOR2I(pos.x, pos.y),
-                                                LAYER_RANGE(layer_to_router(horizon::BoardLayers::TOP_COPPER),
-                                                            layer_to_router(horizon::BoardLayers::BOTTOM_COPPER)),
-                                                via->parameter_set.at(horizon::ParameterID::VIA_DIAMETER),
-                                                via->parameter_set.at(horizon::ParameterID::HOLE_DIAMETER), net,
-                                                VIATYPE::THROUGH));
+    std::unique_ptr<PNS::VIA> pvia(new PNS::VIA(
+            VECTOR2I(pos.x, pos.y), LAYER_RANGE(layer_to_router(span.start()), layer_to_router(span.end())),
+            via->parameter_set.at(horizon::ParameterID::VIA_DIAMETER),
+            via->parameter_set.at(horizon::ParameterID::HOLE_DIAMETER), net,
+            span == horizon::BoardLayers::layer_range_through ? VIATYPE::THROUGH : VIATYPE::BLIND_BURIED));
 
     // via->SetParent( aVia );
     pvia->SetParent(get_parent(via));
@@ -829,12 +871,12 @@ void PNS_HORIZON_IFACE::DisplayItem(const PNS::ITEM *aItem, int aClearance, bool
         std::deque<horizon::Coordi> pts;
         pts.emplace_back(pos.x, pos.y);
         pts.emplace_back(pos.x + 10, pos.y);
-        int la = via_item->Layers().Start();
-        m_preview_items.insert(
-                canvas->add_line(pts, via_item->Diameter(), horizon::ColorP::LAYER_HIGHLIGHT, layer_from_router(la)));
-        la = via_item->Layers().End();
-        m_preview_items.insert(
-                canvas->add_line(pts, via_item->Diameter(), horizon::ColorP::LAYER_HIGHLIGHT, layer_from_router(la)));
+        const auto &via_layers = via_item->Layers();
+        auto layers = board->get_layers_for_range(
+                {layer_from_router(via_layers.Start()), layer_from_router(via_layers.End())});
+        for (const auto la : layers) {
+            m_preview_items.insert(canvas->add_line(pts, via_item->Diameter(), horizon::ColorP::LAYER_HIGHLIGHT, la));
+        }
     }
     else if (aItem->Kind() == PNS::ITEM::ARC_T) {
         auto arc_item = static_cast<const PNS::ARC *>(aItem);
@@ -920,19 +962,18 @@ std::pair<horizon::BoardPackage *, horizon::Pad *> PNS_HORIZON_IFACE::find_pad(i
 horizon::BoardJunction *PNS_HORIZON_IFACE::find_junction(int layer, const horizon::Coordi &c)
 {
     for (auto &it : board->junctions) {
-        if ((layer == 10000 || it.second.layer == layer || it.second.has_via) && it.second.position == c) {
+        if (it.second.layer.overlaps(layer) && it.second.position == c) {
             return &it.second;
         }
     }
     return nullptr;
 }
 
-std::set<horizon::BoardJunction *> PNS_HORIZON_IFACE::find_junctions(const horizon::Coordi &c)
+std::set<horizon::BoardJunction *> PNS_HORIZON_IFACE::find_junctions(const horizon::Via &via)
 {
     std::set<horizon::BoardJunction *> junctions;
-    const auto cu_layers = horizon::LayerRange(horizon::BoardLayers::TOP_COPPER, horizon::BoardLayers::BOTTOM_COPPER);
     for (auto &[uu, ju] : board->junctions) {
-        if (ju.net && ju.position == c && ju.layer.overlaps(cu_layers)) {
+        if (ju.net && ju.position == via.junction->position && ju.layer.overlaps(via.span)) {
             junctions.insert(&ju);
         }
     }
@@ -941,7 +982,7 @@ std::set<horizon::BoardJunction *> PNS_HORIZON_IFACE::find_junctions(const horiz
 
 void PNS_HORIZON_IFACE::AddItem(PNS::ITEM *aItem)
 {
-    // std::cout << "!!!iface add item" << std::endl;
+    // std::cout << "!!!iface add item " << aItem->KindStr() << std::endl;
     switch (aItem->Kind()) {
     case PNS::ITEM::SEGMENT_T:
     case PNS::ITEM::ARC_T: {
@@ -1009,20 +1050,48 @@ void PNS_HORIZON_IFACE::AddItem(PNS::ITEM *aItem)
         PNS::VIA *pvia = static_cast<PNS::VIA *>(aItem);
         auto uu = horizon::UUID::random();
         auto net = get_net_for_code(pvia->Net());
-        auto padstack = pool->get_padstack(rules->get_via_padstack_uuid(net));
+        const horizon::ViaDefinition *vdef = nullptr;
+        if (auto def_uu = get_via_definition_for_code(pvia->Definition())) {
+            vdef = &rules->get_rule_t<horizon::RuleViaDefinitions>().via_definitions.at(def_uu);
+        }
+        horizon::UUID padstack_uuid;
+        if (vdef) {
+            padstack_uuid = vdef->padstack;
+        }
+        else {
+            padstack_uuid = rules->get_via_padstack_uuid(net);
+        }
+        auto padstack = pool->get_padstack(padstack_uuid);
         if (padstack) {
-            auto ps = rules->get_via_parameter_set(net);
+            horizon::ParameterSet ps;
+            if (vdef) {
+                ps = vdef->parameters;
+            }
+            else {
+                ps = rules->get_via_parameter_set(net);
+            }
             auto via = &board->vias
                                 .emplace(std::piecewise_construct, std::forward_as_tuple(uu),
                                          std::forward_as_tuple(uu, padstack))
                                 .first->second;
             via->parameter_set = ps;
+            if (vdef) {
+                via->span = vdef->span;
+                via->definition = vdef->uuid;
+                via->source = horizon::Via::Source::DEFINITION;
+            }
+
+            horizon::BoardJunction temp_junction{horizon::UUID()};
+            temp_junction.position = {pvia->Pos().x, pvia->Pos().y};
+
+            via->junction = &temp_junction;
+            auto junctions = find_junctions(*via);
+            via->junction = nullptr;
 
-            horizon::Coordi c(pvia->Pos().x, pvia->Pos().y);
-            auto junctions = find_junctions(c);
             if (junctions.size()) {
                 auto new_junc = *junctions.begin();
                 via->junction = new_junc;
+                new_junc->layer.merge(via->span);
                 for (auto ju : junctions) {
                     if (ju == new_junc)
                         continue;
@@ -1033,6 +1102,7 @@ void PNS_HORIZON_IFACE::AddItem(PNS::ITEM *aItem)
                             for (auto &it_ft : {&track.from, &track.to}) {
                                 if (it_ft->junc == ju) {
                                     it_ft->connect(new_junc);
+                                    new_junc->connected_tracks.push_back(track_uu);
                                 }
                             }
                         }
@@ -1042,8 +1112,9 @@ void PNS_HORIZON_IFACE::AddItem(PNS::ITEM *aItem)
             else {
                 auto juu = horizon::UUID::random();
                 auto ju = &board->junctions.emplace(juu, juu).first->second;
-                ju->position = c;
+                ju->position = temp_junction.position;
                 ju->net = net;
+                ju->layer = via->span;
                 via->junction = ju;
             }
             via->junction->has_via = true;
@@ -1126,7 +1197,7 @@ void PNS_HORIZON_IFACE::UpdateItem(ITEM *aItem)
         via->junction->position.x = pvia->Pos().x;
         via->junction->position.y = pvia->Pos().y;
         // check if the via's position could merge junctions
-        auto junctions = find_junctions(via->junction->position);
+        auto junctions = find_junctions(*via);
         for (auto ju : junctions) {
             if (ju == via->junction)
                 continue;
