@@ -106,6 +106,9 @@ public:
     horizon::Net *get_net_for_code(int code);
     int get_net_code(const horizon::UUID &uu);
 
+    horizon::UUID get_via_definition_for_code(int code);
+    int get_via_definition_code(const horizon::UUID &uu);
+
     const PNS_HORIZON_PARENT_ITEM *get_parent(const horizon::Track *track);
     const PNS_HORIZON_PARENT_ITEM *get_parent(const horizon::Via *via);
     const PNS_HORIZON_PARENT_ITEM *get_parent(const horizon::BoardHole *hole);
@@ -147,13 +150,16 @@ private:
     std::map<horizon::UUID, int> net_code_map;
     std::vector<horizon::Net *> net_code_map_r;
 
+    std::map<horizon::UUID, int> via_definition_code_map;
+    std::vector<horizon::UUID> via_definition_code_map_r;
+
     int64_t override_routing_offset = -1;
 
     std::list<PNS_HORIZON_PARENT_ITEM> parents;
 
     std::pair<horizon::BoardPackage *, horizon::Pad *> find_pad(int layer, const horizon::Coord<int64_t> &c);
     horizon::BoardJunction *find_junction(int layer, const horizon::Coord<int64_t> &c);
-    std::set<horizon::BoardJunction *> find_junctions(const horizon::Coord<int64_t> &c);
+    std::set<horizon::BoardJunction *> find_junctions(const horizon::Via &via);
     std::set<horizon::BoardJunction *> junctions_maybe_erased;
 };
 } // namespace PNS
