@@ -47,7 +47,7 @@ const LutEnumStr<RuleID> rule_id_lut = {
         {"clearance_silkscreen_exposed_copper", RuleID::CLEARANCE_SILKSCREEN_EXPOSED_COPPER},
         {"track_width", RuleID::TRACK_WIDTH},
         {"clearance_copper", RuleID::CLEARANCE_COPPER},
-        {"single_pin_net", RuleID::SINGLE_PIN_NET},
+        {"single_pin_net", RuleID::CONNECTIVITY},
         {"parameters", RuleID::PARAMETERS},
         {"via", RuleID::VIA},
         {"clearance_copper_other", RuleID::CLEARANCE_COPPER_OTHER},
@@ -56,6 +56,7 @@ const LutEnumStr<RuleID> rule_id_lut = {
         {"package_checks", RuleID::PACKAGE_CHECKS},
         {"preflight_checks", RuleID::PREFLIGHT_CHECKS},
         {"clearance_copper_keepout", RuleID::CLEARANCE_COPPER_KEEPOUT},
+        {"board_connectivity", RuleID::BOARD_CONNECTIVITY},
 };
 
 std::string Rule::layer_to_string(int layer)
