@@ -5,11 +5,13 @@
 #include <glibmm.h>
 #include "nlohmann/json.hpp"
 #include "rule.hpp"
+#include "util/util.hpp"
 
 namespace horizon {
 static const LutEnumStr<RuleMatch::Mode> mode_lut = {
         {"all", RuleMatch::Mode::ALL},
         {"net", RuleMatch::Mode::NET},
+        {"nets", RuleMatch::Mode::NETS},
         {"net_class", RuleMatch::Mode::NET_CLASS},
         {"net_name_regex", RuleMatch::Mode::NET_NAME_REGEX},
         {"net_class_regex", RuleMatch::Mode::NET_CLASS_REGEX},
@@ -24,6 +26,11 @@ RuleMatch::RuleMatch(const json &j)
       net_class(j.at("net_class").get<std::string>()), net_name_regex(j.at("net_name_regex").get<std::string>()),
       net_class_regex(j.value("net_class_regex", ""))
 {
+    if (j.count("nets")) {
+        for (const auto &it : j.at("nets")) {
+            nets.emplace(it.get<std::string>());
+        }
+    }
 }
 
 RuleMatch::RuleMatch(const json &j, const RuleImportMap &import_map) : RuleMatch(j)
@@ -40,7 +47,13 @@ json RuleMatch::serialize() const
     j["net_name_regex"] = net_name_regex;
     if (net_class_regex.size())
         j["net_class_regex"] = net_class_regex;
-
+    if (nets.size()) {
+        auto o = json::array();
+        for (const auto &it : nets) {
+            o.push_back(static_cast<std::string>(it));
+        }
+        j["nets"] = o;
+    }
     return j;
 }
 
@@ -53,6 +66,9 @@ bool RuleMatch::match(const Net *n) const
     case Mode::NET:
         return n && n->uuid == net;
 
+    case Mode::NETS:
+        return n && nets.count(n->uuid);
+
     case Mode::NET_CLASS:
         return n && n->net_class->uuid == net_class;
 
@@ -77,6 +93,7 @@ void RuleMatch::cleanup(const Block *block)
         net = UUID();
     if (!block->net_classes.count(net_class))
         net_class = block->net_class_default->uuid;
+    set_erase_if(nets, [block](const auto &uu) { return block->nets.count(uu) == 0; });
 }
 
 std::string RuleMatch::get_brief(const Block *block) const
@@ -89,6 +106,16 @@ std::string RuleMatch::get_brief(const Block *block) const
         case Mode::NET:
             return "Net " + (net ? Glib::Markup::escape_text(block->nets.at(net).name) : "?");
 
+        case Mode::NETS: {
+            const auto sz = nets.size();
+            if (sz == 0)
+                return "No nets";
+            else if (sz == 1)
+                return "One net";
+            else
+                return std::to_string(nets.size()) + " nets";
+        }
+
         case Mode::NET_CLASS:
             return "Net class " + (net_class ? Glib::Markup::escape_text(block->net_classes.at(net_class).name) : "?");
 
@@ -107,6 +134,16 @@ std::string RuleMatch::get_brief(const Block *block) const
         case Mode::NET:
             return "Net";
 
+        case Mode::NETS: {
+            const auto sz = nets.size();
+            if (sz == 0)
+                return "No nets";
+            else if (sz == 1)
+                return "One net";
+            else
+                return std::to_string(nets.size()) + " nets";
+        }
+
         case Mode::NET_CLASS:
             return "Net class";
 
