@@ -6,12 +6,10 @@
 namespace horizon {
 RuleSymbolChecks::RuleSymbolChecks() : Rule()
 {
-    id = RuleID::SYMBOL_CHECKS;
 }
 
 RuleSymbolChecks::RuleSymbolChecks(const json &j) : Rule(j)
 {
-    id = RuleID::SYMBOL_CHECKS;
 }
 
 json RuleSymbolChecks::serialize() const
@@ -20,7 +18,7 @@ json RuleSymbolChecks::serialize() const
     return j;
 }
 
-std::string RuleSymbolChecks::get_brief(const class Block *block) const
+std::string RuleSymbolChecks::get_brief(const class Block *block, class IPool *pool) const
 {
     return "";
 }
