@@ -83,6 +83,9 @@ bool run_native_filechooser_with_retry(Glib::RefPtr<Gtk::FileChooser> chooser, c
 void listbox_ensure_row_visible(Gtk::ListBox *box, Gtk::ListBoxRow *row);
 void listbox_ensure_row_visible_new(Gtk::ListBox *box, Gtk::ListBoxRow *row);
 
+std::string get_activation_token(Gtk::Window *win);
+void activate_window(Gtk::Window *win, guint32 timestamp, const std::string &token);
+
 #define GET_WIDGET(name)                                                                                               \
     do {                                                                                                               \
         x->get_widget(#name, name);                                                                                    \
