@@ -6,11 +6,13 @@ class MSDAnimator {
 public:
     bool step(double time);
     double get_s() const;
-    void stop();
-    void start();
+    void start(double init = 0);
     float target = 0;
     bool is_running() const;
 
+    void set_params(const MSD::Params &p);
+    const MSD::Params &get_params() const;
+
 private:
     MSD msd;
     bool running = false;
