@@ -24,22 +24,28 @@ void StatusDispatcher::notify()
             revealer->set_reveal_child(true);
         }
         else {
-            timeout_conn = Glib::signal_timeout().connect(
-                    [this] {
-                        revealer->set_reveal_child(false);
-                        return false;
-                    },
-                    750);
+            timeout_conn = Glib::signal_timeout().connect(sigc::mem_fun(*this, &StatusDispatcher::hide_revealer), 750);
         }
     }
-    if (label)
+    if (label) {
         label->set_text(m);
+        label->set_selectable(status == StatusDispatcher::Status::ERROR);
+    }
     if (spinner)
         spinner->property_active() = status == StatusDispatcher::Status::BUSY;
     if (progress_bar) {
         progress_bar->set_visible(progress >= 0);
         progress_bar->set_fraction(progress);
     }
+    if (window) {
+        auto win = window->get_window();
+        if (status == StatusDispatcher::Status::BUSY) {
+            win->set_cursor(Gdk::Cursor::create(win->get_display(), "progress"));
+        }
+        else {
+            win->set_cursor();
+        }
+    }
     Notification n;
     n.status = st;
     n.msg = m;
@@ -47,6 +53,12 @@ void StatusDispatcher::notify()
     s_signal_notified.emit(n);
 }
 
+bool StatusDispatcher::hide_revealer()
+{
+    revealer->set_reveal_child(false);
+    return false;
+}
+
 void StatusDispatcher::attach(Gtk::Label *w)
 {
     label = w;
@@ -67,6 +79,11 @@ void StatusDispatcher::attach(Gtk::ProgressBar *w)
     progress_bar = w;
 }
 
+void StatusDispatcher::attach(Gtk::Window *w)
+{
+    window = w;
+}
+
 void StatusDispatcher::reset(const std::string &m)
 {
     {
