@@ -6,7 +6,7 @@ namespace horizon {
 
 class NetClassButton : public Gtk::ComboBoxText {
 public:
-    NetClassButton(class Block *b);
+    NetClassButton(const class Block &block);
     void set_net_class(const UUID &uu);
     typedef sigc::signal<void, UUID> type_signal_net_class_changed;
     type_signal_net_class_changed signal_net_class_changed()
@@ -16,7 +16,7 @@ public:
     void update();
 
 private:
-    Block *block;
+    const Block &block;
     UUID net_class_current;
 
     type_signal_net_class_changed s_signal_net_class_changed;
