@@ -2,6 +2,7 @@
 #include "pool/ipool.hpp"
 #include "util/sqlite.hpp"
 #include "tag_entry.hpp"
+#include "util/sort_controller.hpp"
 #include <set>
 
 namespace horizon {
@@ -74,6 +75,7 @@ void PoolBrowserPackage::add_sort_controller_columns()
     sort_controller->add_column(0, "packages.name");
     sort_controller->add_column(1, "packages.manufacturer");
     sort_controller->add_column(2, "packages.n_pads");
+    sort_controller->add_column(mtime_column, "packages.mtime");
 }
 
 void PoolBrowserPackage::search()
