@@ -1,6 +1,6 @@
 major = 2
-minor = 5
+minor = 6
 micro = 0
-name = "Kepler"
+name = "Luna"
 
 string = ".".join(str(x) for x in (major, minor, micro))
